-- 当季热卖
Lua_QuarterHotSellPanel = class("Lua_QuarterHotSellPanel", Lua_DisplayObject);
function Lua_QuarterHotSellPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_QuarterHotSellPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.infoBg:SetDimensions(695, 1006 + self.adaptHeight);

	self.dragList = Lua_DragList.new(self.content, 660, 820 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.dragList.tweenId = 2003;
	self.dragList:setListCell(Lua_QuarterHotSellItem, 216, 304, 3);
	self.dragList:setCellSpacing(6, 10);
	self.dragList:setLocation(0, -57);

	self:addLuaEvent("UPDATE_QUARTERHOTSELL_PANEL", self, self.updatePanel);
	self:addLuaEvent("QUARTERHOTSELL_DIAMONDBUY", self, self.diamondBuy);
	self:addLuaEvent("QUARTERHOTSELL_RECHARGEBUY", self, self.rechargeBuy);
end

function Lua_QuarterHotSellPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.dragList:setContentRect(660, 820 + adaptHeight);
	self.infoBg:SetDimensions(695, 1006 + adaptHeight);
end

function Lua_QuarterHotSellPanel:setData(actVo)
	self.actVo = actVo;
	self:startTimer();
	self:updateTime();
end

function Lua_QuarterHotSellPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("QuarterHotSellDownTimer", 1, self, self.updateTime);
	end
end

function Lua_QuarterHotSellPanel:updateTime()
	local timeStr = Lua_TimeTransform.transSeconds16(self.actVo.residueTime, true, true, true);
	self.timeTxt.text = LanUtil.formateStr(630000, timeStr);
	if self.actVo.residueTime <= 0 then
		self.timeTxt.text = nil;
		self:stopTimer();
	end
end

function Lua_QuarterHotSellPanel:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		Lua_CommonUtil.removeTimer(self, self.updateTime);
	end
end

function Lua_QuarterHotSellPanel:updatePanel(msg)
	if msg == nil then
		return;
	end

	table.sort(msg.seller_list,
		function(a, b)
			if (a.num > 0 and b.num > 0) or (a.num <= 0 and b.num <= 0) then
				return a.id < b.id;
			else
				return a.num > b.num;
			end
		end
	);
	self.dragList:setArrayData(msg.seller_list);
end

function Lua_QuarterHotSellPanel:diamondBuy(id)
	if DataCenter.backstageActData:checkActIsEnd(self.actVo) or id == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sBuyQuarterGift(self.actVo.actIdx, id);
end

function Lua_QuarterHotSellPanel:rechargeBuy(id)
	if DataCenter.backstageActData:checkActIsEnd(self.actVo) or id == nil then
		return;
	end
	local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(id);
	if rechargeInfo ~= nil then
		DataCenter.sdkInterface:PointOut(tonumber(rechargeInfo.gold), tonumber(rechargeInfo.money),
			tonumber(rechargeInfo.money_type), tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
	end
end

function Lua_QuarterHotSellPanel:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	self.actVo = nil;
	self:stopTimer();
	self:superCall("dispose");
end










Lua_QuarterHotSellItem = class("Lua_QuarterHotSellItem", Lua_ListCell)
function Lua_QuarterHotSellItem:ctor(p)
	self:superCall("ctor", p, "QuarterHotSellItem_skin");
end

function Lua_QuarterHotSellItem:buildShowItem()
	self:superCall("buildShowItem");

	self.dragList = Lua_DragList.new(self.content, 200, 62, Lua_AxisDefine.Horizontal);
	self.dragList:setLocation(0, -25);
	self:setSubList(self.dragList);
end

function Lua_QuarterHotSellItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	if data.icon_config ~= nil then
		self.giftIcon:setAltas(data.icon_config.icon_atlas, data.icon_config.icon_index);
	end
	self.giftIcon:resetSize();
	self.timesTxt.text = LanUtil.formateStr(630002, data.num);

	local arr = Array();
	if #data.item_list >= 4 then
		for i = 1, #data.item_list do
			arr:add({itemData = data.item_list[i], scale = 0.4, isGray = data.num <= 0});
		end
		self.dragList.canDrag = #data.item_list > 4;
		self.dragList:setListCell(Lua_QuarterHotSellIconCell, 50, 50, 1);
		self.dragList:setContentRect(200, 50);
		self.dragList:setArrayData(arr);
	else
		for i = 1, #data.item_list do
			arr:add({itemData = data.item_list[i], scale = 0.5, isGray = data.num <= 0});
		end
		self.dragList.canDrag = false;
		self.dragList:setListCell(Lua_QuarterHotSellIconCell, 62, 62, 1);
		self.dragList:setContentRect(62 * #data.item_list, 62);
		self.dragList:setArrayData(arr);
	end

	if data.type == 1 then -- 钻石
		if data.price <= 0 then
			self.costTxt:setLangValue(630003);
		else
			local tvo = Lua_ToolVo.createToolVo(Lua_ResourcesDefine.DIAMOND);
			local str = spliceIconStr(tvo.iconAtlas, tvo.iconSprite, tvo.iconWidth * 0.9, tvo.iconHeight * 0.9);
			self.costTxt.text = LanUtil.formateStr("{1} {2}", str, data.price);
		end
	elseif data.type == 2 then -- RMB
		if data.price <= 0 then
			self.costTxt:setLangValue(630003);
		else
			self.costTxt.text = LanUtil.formateStr(630001, data.price);
		end
	end
	self.bg:setGray(data.num <= 0);
	self.costTxt:setGray(data.num <= 0);
	self.giftIcon:setGray(data.num <= 0);
	self.selloutIcon:setEnable(data.num <= 0);
	self:showRedDot(data.price <= 0 and data.num > 0);
end

function Lua_QuarterHotSellItem:showRedDot(bShow)
	if bShow then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(85, 125);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_QuarterHotSellItem:onPressClick()
	if self.data == nil or self.data.id == nil or self.data.num <= 0 then
		return;
	end

	local winPos = LuaUtil.getTouchPosInverseObj(self.dragList.sub);
	for i = 1, self.dragList.showList:getSize() do
		if self.dragList.showList[i]:checkInBound(winPos.x, winPos.y) then
			return;
		end
	end

	if self.data.type == 1 then
		if DataCenter.moneyData:isMoneyEnough(Lua_ResourcesDefine.DIAMOND, tonumber(self.data.price), true, true) then
			Lua_MsgUtil.callFunc("QUARTERHOTSELL_DIAMONDBUY", self.data.id);
		end 
	elseif self.data.type == 2 then
		Lua_MsgUtil.callFunc("QUARTERHOTSELL_RECHARGEBUY", self.data.id);
	end
end

function Lua_QuarterHotSellItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:onMouseDownHandle();
	end
end

function Lua_QuarterHotSellItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		self.pressItem:onMouseUpHandle();
	end
end

function Lua_QuarterHotSellItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.dragList.sub);
	for i = 1, self.dragList.showList:getSize() do
		if self.dragList.showList[i]:checkInBound(winPos.x, winPos.y) then
			return self.dragList.showList[i];
		end
	end
	return nil;
end

function Lua_QuarterHotSellItem:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.pressItem = nil;
	self.data = nil;
	self:superCall("dispose");
end










Lua_QuarterHotSellIconCell = class("Lua_QuarterHotSellIconCell", Lua_ListCell);
function Lua_QuarterHotSellIconCell:ctor(p)
	self:superCall("ctor", p);
end

function Lua_QuarterHotSellIconCell:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon = Lua_ItemIcon.new(self.content);
end

function Lua_QuarterHotSellIconCell:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	if self.itemVo == nil then
		self.itemVo = Lua_ToolVo.createToolVo(data.itemData.id);
	else
		self.itemVo:setData(data.itemData.id);
	end
	self.itemVo:fromServer(data.itemData);
	self.itemIcon:setData(self.itemVo);
	self.itemIcon:setScale(data.scale, data.scale);
	self.itemIcon:setGray(data.isGray);
end

function Lua_QuarterHotSellIconCell:onPressClick()
	if self._data.isGray then
		return;
	end
	self.itemIcon:onItemClick();
end

function Lua_QuarterHotSellIconCell:onMouseDownHandle()
	self.itemIcon:setScale(self._data.scale * 0.95, self._data.scale * 0.95);
end

function Lua_QuarterHotSellIconCell:onMouseUpHandle()
	self.itemIcon:setScale(self._data.scale, self._data.scale);
end

function Lua_QuarterHotSellIconCell:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self._data = nil;
	self.itemVo = nil;
	self:superCall("dispose");
end