-- BOSS挑战(后台)
Lua_BossChallengePanel = class("Lua_BossChallengePanel", Lua_DisplayObject);
function Lua_BossChallengePanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_BossChallengePanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_ItemIconList.new(self.content);
	self.rewardList.pivot = 1;
	self.rewardList.canClick = true;
	self.rewardList.scaleVal = 0.6;
	self.rewardList:setLayout(130, 124, 999);
	self.rewardList:setRectAnchor(1);
	self.rewardList:setLocation(-320, -334, 0);

	local item;
	self.rankArr = Array();
	for i = 1, 3 do
		item = Lua_BossChallengeRankMiniItem.new(self.content);
		item:setRectAnchor(1);
		item:setLocation(184, -312 - (i - 1) * 34, 0);
		item:setData(i);
		self.rankArr:add(item);
	end

	self:addLuaEvent("UPDATE_BOSSCHALLENGE_INFO", self, self.updateServerInfo);
	self:addLuaEvent("UPDATE_BOSSCHALLENGE_RANK_INFO", self, self.updateBossChallengeRankInfo);
	self:addLuaEvent("REQUEST_BOSSCHALLENGE_RANK_INFO", self, self.onRequestRankInfo);
	self:addLuaEvent("REQUEST_BOSSCHALLENGE_RANKREWARD_INFO", self, self.onRequestRankRewardInfo);

	self.preReadTxt:resetSize();
	self.ruleBtn:addClickFuntion(self, self.onRuleClick);
	self.allRankBtn:addClickFuntion(self, self.onAllRankClick);
	self.preReadTxt:addClickFuntion(self, self.onPreReadClick);
	self.rewardBtn:addClickFuntion(self, self.onRewardClick);
	self.challengeBtn:addClickFuntion(self, self.onChallengeClick);
end

function Lua_BossChallengePanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
end

function Lua_BossChallengePanel:setData(data)
	self.data = data;

	self.titleIcon:setAltas(DataCenter.bossChallengeData.atlas, DataCenter.bossChallengeData.title);
	self.titleIcon:resetSize();

	self:onRequestRankInfo(0);
	self:updateServerInfo();
	self:startTimer();
	self:updateLeftTime();
end

function Lua_BossChallengePanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_BossChallengePanel", 1, self, self.updateLeftTime);
	end
end

function Lua_BossChallengePanel:updateLeftTime()
	local time = self.data.residueTime;
	if time <= 0 then
		self.leftTimeTxt:setLangValue(640019);
		self:endTimer();
		return;
	end
	self.leftTimeTxt.text = LanUtil.formateStr(640000, Lua_TimeTransform.transSeconds18(time, true, true, true, false));
end

function Lua_BossChallengePanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.updateLeftTime);
	end
end

function Lua_BossChallengePanel:updateServerInfo()
	local bossChallengeData = DataCenter.bossChallengeData;
	self.rewardList:setArrayData(bossChallengeData.hero_list);

	local str = LanUtil.getValue(640001);
	local attrVo;
	for i = 1, #bossChallengeData.add_prop_list do
		attrVo = DataCenter.attributesUtil:createAttrVo(bossChallengeData.add_prop_list[i].name);
		str = str .. LanUtil.formateStr(640002, attrVo.show_name, bossChallengeData.add_prop_list[i].value * 100);
	end
	self.upAttrTxt.text = str;

	local stageReward = bossChallengeData.daily_hurt_reward;
	if bossChallengeData.daily_max_hurt <= 0 then
		self.hurtTxt.text = LanUtil.formateStr(640003, 0, stageReward[bossChallengeData.curStageIdx].hurt);
	else
		if bossChallengeData.daily_max_hurt > stageReward[#stageReward].hurt then
			self.hurtTxt.text = bossChallengeData.daily_max_hurt;
		else
			self.hurtTxt.text = LanUtil.formateStr(640003, bossChallengeData.daily_max_hurt, stageReward[bossChallengeData.nextStageIdx].hurt);
		end
	end

	local itemInfo = stageReward[bossChallengeData.nextStageIdx].item_list[1];
	local tvo = getConfig("item", itemInfo.id); -- Lua_ToolVo.createToolVo(itemInfo.id);
	self.preReadBtn:setAltas(tvo.atlas, tvo.sprite);

	local recordId = DataCenter.fightData:getRecordIdByTemplateId(Lua_FightDefine.TEMPLATE_ID_BOSSCHALLENGE);
	if recordId > 0 then
		self.challengeBtn:setLangValue(640004);
	else
		self.challengeBtn:setLangValue(640005);
	end

	-- self:setModelShow();
	self:showFightEff(recordId > 0);
	self:updateShowRedDot(bossChallengeData.daily_reward_state == 1);
end

function Lua_BossChallengePanel:setModelShow(param)
	if self.modelScenePanel == nil then
		local monsterConfig = Lua_MonsterPlayerConfigData.getConfigData(DataCenter.bossChallengeData.monster_id);
		local monsterData = Lua_MonsterConfigData.getMonsterConfig(monsterConfig.fighter_list[1][1][1]);
		local data = monsterData.heroVo;
		if param ~= nil then
			self.modelScenePanel = param;
		else
			self.modelScenePanel = Lua_ModelScenePanel.new();
		end
		self.modelScenePanel:setParent(self.content);
		self.modelScenePanel:setRotBgDimensions(720, 720);
		self.modelScenePanel:setRotBgPos(0, 195);
		
		if not self.modelScenePanel.bShowModel then
			self.modelScenePanel:setModelDir(data.uiModelDir); -- 模型rotate
			self.modelScenePanel:setModelScale(data.uiModelScale); -- 模型scale
			self.modelScenePanel:addActIdEffs(Lua_ThingDefine.UIWAIT, data.poseActEffs); -- ui待机wait
			self.modelScenePanel:addActIdEffs(Lua_ThingDefine.UISHOW, data.showActEffs); -- ui展示show
			self.modelScenePanel:showModelScene(DataCenter.bossChallengeData.scene_id, data.uiModelUrl, data.uiModelAvatarName, data.uiModelCamController, true);
			self.modelScenePanel:setModelAct(data.uiShowAct, Lua_ThingDefine.UIWAIT, true);
		end
		self:showSkillFun(monsterData.skill_list);
	end
end

function Lua_BossChallengePanel:returnModel()
	if self.modelScenePanel ~= nil then
		self.modelScenePanel:dispose()
		self.modelScenePanel = nil
	end
end

function Lua_BossChallengePanel:showSkillFun(skillList)
	if self.skillArr == nil then
		self.skillArr = Array();
	end

	local dataLen = skillList == nil and 0 or #skillList;
	local arr = Array();
	local configData;
	for i = 1, dataLen do
		configData = Lua_SkillConfigData.getConfigData(skillList[i]);
		if configData.show_type ~= 1 then
			arr:add(configData);
		end
	end

	dataLen = arr:getSize();
	local posList;
	if dataLen == 3 then
		posList = {{-185, 475}, {0, 460}, {185, 475}};
	elseif dataLen == 4 then
		posList = {{-238, 487}, {-80, 460}, {80, 460}, {238, 487}};
	elseif dataLen == 5 then
		posList = {{-304, 595}, {-185, 475}, {0, 460}, {185, 475}, {304, 595}};
	end

	local item;
	for i = 1, dataLen do
		item = self.skillArr[i];
		if item == nil then
			item = Lua_SkillIconItem.new(self.content);
			item:setRectAnchor(7);
			item:setCanClick(true);
			self.skillArr:add(item);
		end
		item:setData(arr[i]);
		item:setLocation(posList[i][1], posList[i][2], 0);
		item:setScale(0.9, 0.9, 0.9);
	end
	arr:clear();
	arr = nil;
end

function Lua_BossChallengePanel:showFightEff(bShow)
	if bShow then
		if self.fightEff == nil then
			self.fightEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_ty_zdbs_0101", "ui_ty_zdbs_0101", 90, 235);
			self.fightEff.anchorValue = 7;
			self.fightEff:setScale(0.5, 0.5, 0.5);
		end
		self.fightEff:setEnable(true);
	else
		if self.fightEff then
			self.fightEff:setEnable(false);
		end
	end
end

function Lua_BossChallengePanel:updateShowRedDot(bShow)
	if bShow then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(-200, 253, 0);
			self.redPoint:setRectAnchor(7);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

-- 更新前三名信息
function Lua_BossChallengePanel:updateBossChallengeRankInfo(msg)
	if msg == nil then
		return;
	end

	local list = msg.rank_list;
	-- table.sort( list, function(a, b) return a.rank < b.rank end);
	local len = #list;
	for i = 1, 3 do
		if len >= i then
			self.rankArr[i]:setData(i, list[i]);
		else
			self.rankArr[i]:setData(i, nil);
		end
	end
end

-- 请求排行信息
function Lua_BossChallengePanel:onRequestRankInfo(page)
	if page == nil then
		return;
	end
	self:onBossChallengeOperate(1, page);
end

-- 请求排行奖励信息
function Lua_BossChallengePanel:onRequestRankRewardInfo()
	self:onBossChallengeOperate(2);
end

-- 活动说明
function Lua_BossChallengePanel:onRuleClick(go)
	local tipsData = { des = self.data.help_des, posX = 180, posY = -270 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

-- 打开BOSS挑战排行榜界面
function Lua_BossChallengePanel:onAllRankClick(go)
	self:onBossChallengeOperate(3);
end

-- 打开BOSS挑战个人阶段伤害界面
function Lua_BossChallengePanel:onPreReadClick(go)
	self:onBossChallengeOperate(4);
end

-- 请求每日奖励
function Lua_BossChallengePanel:onRewardClick(go)
	self:onBossChallengeOperate(5);
end

function Lua_BossChallengePanel:onChallengeClick(go)
	local recordId = DataCenter.fightData:getRecordIdByTemplateId(Lua_FightDefine.TEMPLATE_ID_BOSSCHALLENGE);
	if recordId > 0 then
		DataCenter.fightData:showFightToStageByRid(recordId);
		return;
	end
	self:onBossChallengeOperate(6);
end

function Lua_BossChallengePanel:onBossChallengeOperate(operateType, param)
	if self.data == nil then
		return;
	end
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	if operateType == 1 then
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sBossChallengeRankInfo(self.data.actIdx, param);
	elseif operateType == 2 then
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sBossChallengeRankRewardInfo(self.data.actIdx);
	elseif operateType == 3 then
		Lua_WindowUtil.openWin("Lua_BossChallengeRankWindow", Lua_WinParam.ACTION_OPEN);
	elseif operateType == 4 then
		Lua_WindowUtil.openWin("Lua_BossChallengeHurtRewardWindow", Lua_WinParam.ACTION_OPEN);
	elseif operateType == 5 then
		local drawState = DataCenter.bossChallengeData.daily_reward_state;
		if drawState == 0 then
			Lua_WindowUtil.openWin("Lua_BossChallengeShowRewardWindow", Lua_WinParam.ACTION_OPEN, 1);
		elseif drawState == 1 then
			Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sBossChallengeDailyReward(self.data.actIdx);
		else
			OperateAlert.showLangValue(640006);
		end
	elseif operateType == 6 then
		local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_BOSSCHALLENGE);
		DataCenter.preLoadData:preShowScene("Lua_BossOrHeroChallengeLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, nil, sceneId, 0);
	end
end

function Lua_BossChallengePanel:onSceneShow(param)
	param = {
		template_id = Lua_FightDefine.TEMPLATE_ID_BOSSCHALLENGE,
		monster_player_id = DataCenter.bossChallengeData.monster_id
	};
	Lua_WindowUtil.openWin("Lua_BossOrHeroChallengeLineupWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_BossChallengePanel:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.rankArr ~= nil then
		self.rankArr:dispose();
		self.rankArr:clear();
		self.rankArr = nil;
	end
	if self.skillArr ~= nil then
		self.skillArr:dispose();
		self.skillArr:clear();
		self.skillArr = nil;
	end
	if self.fightEff ~= nil then
		self.fightEff:dispose();
		self.fightEff = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	DataCenter.preLoadData:removeBySign("Lua_BossOrHeroChallengeLineupWindow", self, self.onSceneShow);
	self:returnModel();
	self:endTimer();
	self.data = nil;
	
	self:superCall("dispose");
end










Lua_BossChallengeRankMiniItem = class("Lua_BossChallengeRankMiniItem", Lua_ListCell);
function Lua_BossChallengeRankMiniItem:ctor(p)
	self:superCall("ctor", p, "BossChallengeRankMiniItem_skin");
end

function Lua_BossChallengeRankMiniItem:setData(rank, data)
	self.rankIcon:setAltas("boss_challenge_atlas", "xui_boos_label_"..rank);
	self.rankIcon:resetSize();

	if data == nil then
		self.nameTxt:setLangValue(640007);
	else
		self.nameTxt.text = data.player_show.name;
	end
end