-- BOSS挑战排行榜界面
Lua_BossChallengeRankWindow = class("Lua_BossChallengeRankWindow", Lua_Window);
function Lua_BossChallengeRankWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_BossChallengeRankWindow";
	self.skinName = "BossChallengeRankWindow_skin";
	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.isFullSizeWin = true;
end

function Lua_BossChallengeRankWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarPosList = {{0, -255, 0}, {-236, -270, 0}, {236, -270, 0}};
	self.avatarScale = {0.9, 0.8, 0.8};

	self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content);
	self.roleInfoPanel:setRectAnchor(1);

	self.rankList = Lua_DragList.new(self.content, 688, 540 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.rankList.callBackOwner = self;
	self.rankList.turnPageCallBack = self.turePage;
	self.rankList:setListCell(Lua_BossChallengeRankItem, 688, 125, 1);
	self.rankList:setCellSpacing(0, 5);
	self.rankList:setLocation(0, -185, 0);

	self.rewardBtn:addClickFuntion(self, self.onRewardClick);

	self:addLuaEvent("UPDATE_BOSSCHALLENGE_RANK_INFO", self, self.updateBossChallengeRankInfo);
	self:turePage(0);
end

function Lua_BossChallengeRankWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.rankList:setContentRect(688, 540 + self.adaptHeight)
end

function Lua_BossChallengeRankWindow:turePage(page)
	page = page or 1;
	Lua_MsgUtil.callFunc("REQUEST_BOSSCHALLENGE_RANK_INFO", page);
end

function Lua_BossChallengeRankWindow:updateBossChallengeRankInfo(msg)
	if msg == nil then
		return;
	end

	local list = msg.rank_list;
	-- table.sort( list, function(a, b) return a.rank < b.rank end);
	self:updateMyRank(msg.self_rank);
	self:updateTopRank(list);
	self:updateRankList(list, msg.is_end == 1);
	self:showNone(#list <= 3);
end

function Lua_BossChallengeRankWindow:updateMyRank(info)
	if info == nil then
		self.myNoRankIcon:setEnable(true);
		self.myNameTxt:setEnable(false);
		self.myHurtTxt:setEnable(false);
		if self._myRankNum then self._myRankNum:setEnable(false) end
		if self._myAvatarItem then self._myAvatarItem:setEnable(false) end
	else
		if info.rank == 0 then
			self.myNoRankIcon:setEnable(true);
			if self._myRankNum then self._myRankNum:setEnable(false) end
		else
			self.myNoRankIcon:setEnable(false);
			self.myRankNum.num = info.rank;
		end
		self.myAvatarItem:setRoleId(info.player_show.id);
		self.myAvatarItem:setRoleDressUp(info.player_show.dress_info, true);
		self.myAvatarItem:setRoleLevel2(info.player_show.level);
		self.myNameTxt.text = info.player_show.name;
		self.myHurtTxt.text = info.value;
	end
end

function Lua_BossChallengeRankWindow:updateTopRank(list)
	local serverTxt;
	local valueTxt;
	local nameTxt;
	local avatarStr;
	for i = 1, 3 do
		rankInfo = list[i];
		serverTxt = "serverNameTxt_" .. i;
		nameTxt = "nameTxt_" .. i;
		valueTxt = "valueTxt_" .. i;
		avatarStr = "avatarItem_" .. i;
		if self[avatarStr] == nil then
			self[avatarStr] = Lua_AvatarItem.new(self.content);
			self[avatarStr]:setLocation(self.avatarPosList[i][1], self.avatarPosList[i][2], self.avatarPosList[i][3]);
			self[avatarStr]:setScale(self.avatarScale[i], self.avatarScale[i]);
			self[avatarStr]:setRectAnchor(1);
		end
		if rankInfo == nil then
			self[serverTxt].text = "";
			self[nameTxt]:setLangValue(640007);
			self[valueTxt].text = "";
			self[avatarStr]:init();
		else
			self[serverTxt].text = LanUtil.formateStr(640008, rankInfo.player_show.server_prev);
			-- self[serverTxt]:setEnable(rankInfo.player_show.server_prev ~= nil);
			self[nameTxt].text = rankInfo.player_show.name;
			self[valueTxt].text = rankInfo.value;

			self[avatarStr]:setRoleId(rankInfo.player_show.id);
			self[avatarStr]:setRoleDressUp(rankInfo.player_show.dress_info, true);
			self[avatarStr]:setRoleLevel2(rankInfo.player_show.level);
		end
	end
end

function Lua_BossChallengeRankWindow:updateRankList(list, isPageEnd)
	self.rankList.isPageEnd = isPageEnd;
	if #list <= 3 then return; end
	self.rankList:setArrayData(list, 4);
end

function Lua_BossChallengeRankWindow:showNone(state)
	if state then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createImage(self.content, "/images/common/xui_common_widget_029.png", 0, -174, 0, 0)

			self.noneText = UICreate.createLabel(self.content, nil, 113, -140, 100, 40, 40)
			self.noneText.pivotValue = 4
			self.noneText.fontName = Lua_MyUISettings.huakangFontName
			self.noneText.alignmentValue = 4
			self.noneText.horizontalOverflowValue = 1
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("E3D7DA")
			self.noneText:setLangValue(640009);
		end
		self.noneIcon:setEnable(true)
		self.noneText:setEnable(true)
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false)
			self.noneText:setEnable(false)
		end
	end
end

function Lua_BossChallengeRankWindow.Get:myRankNum()
	if self._myRankNum == nil then
		self._myRankNum = Lua_NumberImage.new(self.content);
		self._myRankNum:setRectAnchor(7);
		self._myRankNum:setLocation(-270.5, 186, 0);
		self._myRankNum.numOffsetX = -4;
		self._myRankNum.numAtlas = "number";
		self._myRankNum.preStr = "xui_phb_number_";
	end
	self._myRankNum:setEnable(true);
	return self._myRankNum;
end

function Lua_BossChallengeRankWindow.Get:myAvatarItem()
	if self._myAvatarItem == nil then
		self._myAvatarItem = Lua_AvatarItem.new(self.content);
		self._myAvatarItem:setRectAnchor(7);
		self._myAvatarItem:setScale(0.7, 0.7, 0.7);
		self._myAvatarItem:setLocation(-147, 186, 0);
	end
	self._myAvatarItem:setEnable(true);
	return self._myAvatarItem;
end

function Lua_BossChallengeRankWindow:onRewardClick(go)
	Lua_WindowUtil.openWin("Lua_BossChallengeRankRewardWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_BossChallengeRankWindow:dispose()
	if self.roleInfoPanel then
		self.roleInfoPanel:dispose();
		self.roleInfoPanel = nil;
	end
	if self.rankList then
		self.rankList:dispose();
		self.rankList = nil;
	end
	if self.noneIcon then
		self.noneIcon:dispose();
		self.noneIcon = nil;
	end
	if self.noneText then
		self.noneText:dispose();
		self.noneText = nil;
	end
	if self._myRankNum then
		self._myRankNum:dispose();
		self._myRankNum = nil;
	end
	if self._myAvatarItem then
		self._myAvatarItem:dispose();
		self._myAvatarItem = nil;
	end
	self:superCall("dispose");
end










Lua_BossChallengeRankItem = class("Lua_BossChallengeRankItem", Lua_ListCell);
function Lua_BossChallengeRankItem:ctor(p)
	self:superCall("ctor", p, "BossChallengeRankItem_skin");
end

function Lua_BossChallengeRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.7, 0.7, 0.7);
	self.avatarItem:setLocation(-147, 0, 0);
end

function Lua_BossChallengeRankItem:setData(data)
	self.data = data;

	self.numTxt.text = data.rank;
	self.avatarItem:setRoleId(data.player_show.id);
	self.avatarItem:setRoleDressUp(data.player_show.dress_info, true);
	self.avatarItem:setRoleLevel2(data.player_show.level);

	self.nameTxt.text = data.player_show.name;
	self.hurtTxt.text = data.value;
end

function Lua_BossChallengeRankItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil
	end
	self:superCall("dispose");
end