-- 兑换活动优化
Lua_CashRewardPanel = class("Lua_CashRewardPanel", Lua_DisplayObject);
function Lua_CashRewardPanel:ctor(p)
	self:superCall("ctor", p, "CashRewardPlane_skin");
end

function Lua_CashRewardPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.iconSp_1:setEnable(false);
	self.iconSp_2:setEnable(false);
	self.iconNumTxt.text = nil;
	self.leftTimeTxt.text = nil;
	self.textArea = Lua_TextArea.new(self.contentObj, 600, 140);
	self.textArea:setLocation(-16, 631);
	self.textArea:setRectAnchor(7);

	self.rewardList = Lua_DragList.new(self.contentObj, 600, 120, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_CashRewardItem, 120, 120, 1);
	self.rewardList:setLocation(2, 388);
	self.rewardList:setRectAnchor(7);
	self.rewardList:setCellSpacing(10, 0);

	self.addSp:addClickFuntion(self,self.onClickAddSp);
	self.cashRewardBtn:addClickFuntion(self,self.gotoCashReward);
	self:addLuaEvent("PACK_ITEMS_UPDATE", self, self.updateCostNum);--道具数量增加时更新红点
	self:addLuaEvent("MONEY_UPDATE", self, self.updateCostNum); 
	self:addLuaEvent("UPDATE_CASHREWARD_INFO", self, self.updateServerInfo);
end

function Lua_CashRewardPanel:setData(data)
	self.data = data;
end

function Lua_CashRewardPanel:updateServerInfo(activeId)
	-- local curRoundInfo = DataCenter.cashRewardData:getRoundConfigDicById(self.round);
	local activityData = DataCenter.cashRewardData:getCashRewardDataByActiveId(activeId);
	if activityData == nil then
		self.activeId = nil;
		return;
	else
		self.activeId = activeId;
	end

	local str = "";
	local actVo = DataCenter.backstageActData:getActVoByIdx(self.activeId);
	if actVo ~= nil then
		str = actVo.help_des or "";
	end
	self.textArea:setText(str, 24, 1.1);

	local costId = activityData.costId;
	local moneyTypeCount = DataCenter.packData:getItemCountById(costId);
	local tvo = Lua_ToolVo.createToolVo(costId);
	self.iconSp_1:setAltas(tvo.atlas, tvo.sprite);
	self.iconSp_2:setAltas(tvo.atlas, tvo.sprite);
	self.iconSp_1:setEnable(true);
	self.iconSp_2:setEnable(true);
	self.iconNumTxt.text = moneyTypeCount;

	self.remainTime = activityData.dropCloseTime;
	self:startTimer();

	local rewards = activityData.previewRewards or {};
	local distance = 120 + 10; 
	local recWidth = #rewards <= 4 and #rewards * distance - 10 or distance * 4.5 - 10 * 0.5;
	self.rewardList.canDrag = #rewards > 4;
	self.rewardList:setContentRect(recWidth, 120, false);
	self.rewardList:setArrayData(rewards);

	self:updateRedPoint();
end

function  Lua_CashRewardPanel:updateRedPoint()
	local bShow = DataCenter.cashRewardData:checkShopBtnRedPoint(self.activeId);
	self:showRedDot(bShow == true); -- 前往兑换按钮是否显示红点
end

function Lua_CashRewardPanel:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("Lua_CashRewardPanel_Time", 1, self, self.updateLeftTime);
		self:updateLeftTime();
	end
end

function Lua_CashRewardPanel:updateLeftTime()
	local residueTime = self.remainTime - DataCenter.roleData.serverTime;
	if residueTime <= 0 then
		self.leftTimeTxt:setLangValue(360000);
		self:endTimer();
		return;
	end
	self.leftTimeTxt.text = LanUtil.formateStr(360001, Lua_TimeTransform.transSeconds16(residueTime, true, true, true, false));
end

function Lua_CashRewardPanel:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

function Lua_CashRewardPanel:updateCostNum(dic)
	local activityData = DataCenter.cashRewardData:getCashRewardDataByActiveId(self.activeId);
	if activityData ~= nil then
		local costId = activityData.costId;
		if dic ~= nil and dic[costId] ~= nil then
			self:updateRedPoint();
			self.iconNumTxt.text = DataCenter.packData:getItemCountById(costId);
		end
	end
end

function Lua_CashRewardPanel:gotoCashReward()
	if self.data == nil then
		return;
	end
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	Lua_WindowUtil.openWin("Lua_CashShopWindow", Lua_WinParam.ACTION_OPEN, self.activeId);
end

-- 红点
function Lua_CashRewardPanel:showRedDot(val)
    if val == true then
        if self.redPoint == nil then
            self.redPoint = Lua_RedPointIcon.new(self.cashObj, self.redPointId);
            self.redPoint:setLocation(102, 259, 0);
            self.redPoint:setRectAnchor(7);
            self.redPoint:createRedPointEff();
        end
        self.redPoint:updateRedPointShow(true);
    else
        if self.redPoint ~= nil then
            self.redPoint:updateRedPointShow(false);
        end
    end
end

function Lua_CashRewardPanel:onClickAddSp()
	local activityData = DataCenter.cashRewardData:getCashRewardDataByActiveId(self.activeId);
	if activityData ~= nil then
		local costId = activityData.costId;
		DataCenter.packUtil:openPathWindow(costId, false);
	end
end

function Lua_CashRewardPanel:dispose()
	self.data = nil;
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self:endTimer();
	self:superCall("dispose");
end










Lua_CashRewardItem = class("Lua_CashRewardItem", Lua_ItemIconCell)
function Lua_CashRewardItem:buildShowItem()
	self:superCall("buildShowItem")

	self.itemIcon:setScale(0.95, 0.95, 0.95);
end

function Lua_CashRewardItem:setData(data)
	self:superCall("setData", data);
	self.itemIcon:showText(4, nil);
end



