-- 兑换商店
Lua_CashShopWindow = class("Lua_CashShopWindow", Lua_Window)
function Lua_CashShopWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER
	self.windowName = "Lua_CashShopWindow";
	self.skinName = "CashShopWindow_skin";
	self.isFullSizeWin = true;
	self.showBackBtn = true;
	self.showWinBg = true;
	self.winBgPath = "/images/cash_reward/xui_dhhd_bg_2.jpg";
end

function Lua_CashShopWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.residueTimeTxt.text = nil;
	self.iconNumTxt.text = nil;
	self.iconSp:setEnable(false);
	self.itemListBg:SetDimensions(699, 973 + self.adaptHeight);
	self.backBtn:setLocation(90, 83);

	self.rewardList = Lua_DragList.new(self.content, 667, 830 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.rewardList:setListCell(Lua_CashShopRewardCell, 324, 151, 2);
	self.rewardList:setLocation(4, -370);
	self.rewardList:setRectPivot(1)
	self.rewardList:setRectAnchor(1);
	self.rewardList:setCellSpacing(12, 4);
	self.rewardList.tweenId = 2003;

	self.addSp:addClickFuntion(self, self.onClickAddSp);
	self:addLuaEvent("PACK_ITEMS_UPDATE", self, self.updateCostNum);--道具数量增加时更新红点
	self:addLuaEvent("MONEY_UPDATE", self, self.updateCostNum); 
	self:addLuaEvent("UPDATE_CASHREWARD_INFO", self, self.updateServerInfo);
end

function Lua_CashShopWindow:showWin(param)
	self:superCall("showWin", param);

	self.activeId = param;
	DataCenter.cashRewardData.curShopWinActivityId = self.activeId;
	local actVo = DataCenter.backstageActData:getActVoByIdx(self.activeId);
	if actVo ~= nil then
		self:createMoney(actVo.money_list);
		-- 活动关闭时间戳或道具掉落时间戳
		self.remainTime = actVo.endTick;
		self:startTimer();
	end

	self:updateServerInfo();
end

function Lua_CashShopWindow:createMoney(list)
	local num = list == nil and 0 or #list;
	if num == 0 then
		if self.topBg then
			self.topBg:setEnable(false);
		end
	else
		if self.topBg == nil then
			self.topBg = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_036", 0, 0, 720, 52);
			self.topBg.anchorValue = 1;
			self.topBg.pivotValue = 1;
		end
		self.topBg:setEnable(true);
	end

	if self.moneyList == nil then
		self.moneyList = Array();
	end
	local len = self.moneyList:getSize();
	local maxLen = num > len and num or len;
	local item;
	for i = 1, maxLen do
		item = self.moneyList[i];
		if i > num then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_MoneyItem.new(self.content);
				self.moneyList:add(item);
			else
				item:setEnable(true);
			end
			item:setRectAnchor(1);
			item:setLocation(249 - (i - 1) * 190, -26, 0);
			item:setCanClick(true);
			item:setMoney(list[i]);
		end
	end
end

function Lua_CashShopWindow:onScreenResize()
	self:superCall("onScreenResize");

	self.itemListBg:SetDimensions(699, 973 + self.adaptHeight);
	self.rewardList:setContentRect(675, 840 + self.adaptHeight);
end

function Lua_CashShopWindow:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("Lua_CashShopWindow_Time", 1, self, self.updateLeftTime);
		self:updateLeftTime();
	end
end

function Lua_CashShopWindow:updateLeftTime()
	local residueTime = self.remainTime - DataCenter.roleData.serverTime;
	if residueTime <= 0 then
		self.residueTimeTxt:setLangValue(360000);
		self:endTimer();
		return;
	end
	self.residueTimeTxt.text = LanUtil.formateStr(360001, Lua_TimeTransform.transSeconds16(residueTime, true, true, true, false)) --"兑换剩余："..;
end

function Lua_CashShopWindow:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

function Lua_CashShopWindow:updateServerInfo(activeId)
	if activeId ~= nil and self.activeId ~= activeId then
		return;
	end

	local activityData = DataCenter.cashRewardData:getCashRewardDataByActiveId(self.activeId);
	if activityData == nil then
		return;
	end

	local costId = activityData.costId;
	local hasCount = DataCenter.packData:getItemCountById(costId);
	local tvo = Lua_ToolVo.createToolVo(costId);
	self.iconSp:setAltas(tvo.atlas, tvo.sprite);
	self.iconSp:setEnable(true);
	self.iconNumTxt.text = hasCount;

	local shopItems = activityData.shopItems or {};
	self.rewardList:setArrayData(shopItems);
end

function Lua_CashShopWindow:onClickAddSp()
	local activityData = DataCenter.cashRewardData:getCashRewardDataByActiveId(self.activeId);
	if activityData ~= nil then
		local costId = activityData.costId;
		DataCenter.packUtil:openPathWindow(costId, false);
	end
end

function Lua_CashShopWindow:updateCostNum(dic)
	local activityData = DataCenter.cashRewardData:getCashRewardDataByActiveId(self.activeId);
	if activityData ~= nil then
		local costId = activityData.costId;
		if dic ~= nil and dic[costId] ~= nil then
			self.iconNumTxt.text = DataCenter.packData:getItemCountById(costId);
		end
	end
end

function Lua_CashShopWindow:dispose()
	DataCenter.cashRewardData.curShopWinActivityId = nil;
	if self.rewardList ~= nil then 
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.moneyList ~= nil then
		self.moneyList:dispose();
		self.moneyList:clear();
		self.moneyList = nil;
	end

	self:endTimer();
	self:superCall("dispose");
end







-------------------------------------------------------
Lua_CashShopRewardCell = class("Lua_CashShopRewardCell", Lua_ListCell);
function Lua_CashShopRewardCell:ctor(p)
    self:superCall("ctor", p, "CashShopItem_skin");
end

function Lua_CashShopRewardCell:buildShowItem()
	self:superCall("buildShowItem");

	self.shopIcon = Lua_ItemIcon.new(self.content);
	self.shopIcon:setScale(0.95, 0.95, 0.95);
	self.shopIcon:setLocation(-83,4);
	self.shopIcon:setSiblingIndex(4);
end

function Lua_CashShopRewardCell:setData(data)
	self.shopId = data;
	self.costId = nil;
	self.resideCount = nil;
	if data == nil then
		return;
	end

	self.activeId = DataCenter.cashRewardData.curShopWinActivityId;
	local shopItem = DataCenter.cashRewardData:getSingleShopItem(self.activeId, self.shopId);
	if shopItem == nil then
		return;
	end

	local costCount = shopItem.costCount;
	local tvo = Lua_ToolVo.createToolVo(shopItem.costId, costCount);
	self.shopIcon:setData(tvo);
	self:setTxtDisplay(tvo.name);

	local activityData = DataCenter.cashRewardData:getCashRewardDataByActiveId(self.activeId);
	if activityData ~= nil then
		self.costId = activityData.costId;
		tvo = Lua_ToolVo.createToolVo(self.costId);
		self.iconSp:setAltas(tvo.atlas, tvo.sprite);
		
		local hasCount = DataCenter.packData:getItemCountById(self.costId);
		local price = shopItem.price;
		self.iconPriceTxt.text = hasCount < price and LanUtil.formateStr(360003, price) or LanUtil.formateStr(360004, price);
		self.resideCount = shopItem.limitCount - shopItem.buyTime;
		self.resideCount = self.resideCount < 0 and 0 or self.resideCount;
		self.limitTimetxt.text = LanUtil.formateStr(360002, self.resideCount);
		self.recommondSp:setEnable(shopItem.recommend);
		self.maskSp:setEnable(self.resideCount <= 0);
		self.sellOutSp:setEnable(self.resideCount <= 0);
	end
end

function Lua_CashShopRewardCell:setTxtDisplay(str)
	self.rewardNameTxt.text = str;
	self.rewardNameTxt:resetSize();
    if self.rewardNameTxt.width > 133 then
        self.rewardNameTxt:setEnable(false);
        if self.scrollText == nil then
            self.scrollText = Lua_ScrollText.new(self.content, Lua_AxisDefine.Horizontal, 133, 24);
            self.scrollText:setLocation(60, 41, 0);
            self.scrollText:setTextStyle(133, 24, Lua_MyUISettings.huakangFontName, 24, "6F5144", 0, "555555");
        end
        self.scrollText:setEnable(true);
        self.scrollText:setShowTxt(str);
    else
        self.rewardNameTxt:setEnable(true);
        if self.scrollText then
            self.scrollText:setEnable(false);
        end
    end
end

function Lua_CashShopRewardCell:onPressClick()
	if self.shopId == nil then
		return;
	end

	local shopItem = DataCenter.cashRewardData:getSingleShopItem(self.activeId, self.shopId);
	if shopItem == nil then
		return;
	end

	local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
	if self.shopIcon:checkInBound(winPos.x, winPos.y) then
		local tvo = Lua_ToolVo.createToolVo(shopItem.costId, shopItem.costCount);
		DataCenter.packUtil:showItemInfo(tvo);
		return;
	end
	
	local actVo = DataCenter.backstageActData:getActVoByIdx(self.activeId);
	if actVo == nil or DataCenter.backstageActData:checkActIsEnd(actVo) then
		return;
	end

	if self.resideCount ~= nil and self.resideCount <= 0 then
		OperateAlert.showLangValue(360005);
		return;
	end
	
	local hasCount = DataCenter.packData:getItemCountById(self.costId);
	if hasCount < shopItem.price then
		DataCenter.packUtil:openPathWindow(self.costId, false);
	else
		local param = {
			id = shopItem.costId, -- 购买道具id
			itemCount = shopItem.costCount, -- 购买一份商品所携带的数量
			showStyle = 2,
			limitCount = self.resideCount, -- 限购数量，小于0不显示， = 0显示不限购， 默认为1,
			costId = self.costId, -- 消耗道具id
			costCount = shopItem.price, -- 消耗道具数量
			tipStr = "",
			isShowTipWindow = true, -- 点击购买按钮时，是否显示提示窗口
			isShowBackBtn = false, -- 是否显示返回按钮
			cancelBtnStr = LanUtil.getValue(125051), -- 默认取消
			sureBtnStr = LanUtil.getValue(125052), -- 默认确定
			owner = self, 
			callFunc = self.onSureBuy, -- 回调事件
			priceStyle = 1, -- 价格显示类型
			font_size = 26, -- tipWindow文本字体大小
			iconWidth = 46,
			iconHeight = 46
		}; 
		Lua_WindowUtil.openWin("Lua_ShoppingGoodsWindow", Lua_WinParam.ACTION_OPEN, param);
	end
end

function Lua_CashShopRewardCell:onSureBuy(id, selectNum)
	Lua_ProxyManager.getProxy("Lua_ExcellentActivityProxy"):sReceivedCashReward(self.activeId, self.shopId, selectNum );
end

function Lua_CashShopRewardCell:dispose()
	if self.scrollText ~= nil then
		self.scrollText:dispose();
		self.scrollText = nil;
	end
	if self.shopIcon ~= nil then
		self.shopIcon:dispose();
		self.shopIcon = nil;
	end

	self:superCall("dispose");
end
