-- 累计充值
Lua_CumulateRechargePanel = class("Lua_CumulateRechargePanel", Lua_DisplayObject);
function Lua_CumulateRechargePanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_CumulateRechargePanel:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 667, 810 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList.tweenId = 2002;
	self.itemList:setListCell(Lua_CumulateRechargeItem, 667, 172, 1);
	self.itemList:setLocation(0, -116, 0);

	self:addLuaEvent("CUMULATE_RECHARGE_INFO", self, self.updateServerInfo);
	self:addLuaEvent("CUMULATE_RECHARGE_OPERATE", self, self.onItemOperate);

	self.ruleIcon:addClickFuntion(self, self.onRuleClick);
end

function Lua_CumulateRechargePanel:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:stopTimer();
	self.data = nil;
	self:superCall("dispose");
end

function Lua_CumulateRechargePanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.itemList:setContentRect(667, 810 + adaptHeight);
end

function Lua_CumulateRechargePanel:setData(data)
	self.data = data;

	if data.residueTime > 0 then
		self:startTimer();
	else
		self:stopTimer();
	end
	self:onTimer();
end

function Lua_CumulateRechargePanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("CUMULATE_RECHARGE_TIMER", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_CumulateRechargePanel:onTimer()
	if self.data.residueTime > 0 then
		self.timeTxt.text = LanUtil.formateStr(202101, Lua_TimeTransform.transSeconds18(self.data.residueTime));
	else
		self:stopTimer();
		self.timeTxt.text = LanUtil.formateStr(202101, Lua_TimeTransform.transSeconds18(0));
	end
end

function Lua_CumulateRechargePanel:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_CumulateRechargePanel:updateServerInfo(msg)
	if msg == nil then
		return;
	end

	self.moneyTxt.text = LanUtil.formateStr(202102, tostring(msg.recharge_money));
	table.sort( msg.gear_list, 
		function(a, b) 
			if a.state == 0 and b.state == 1 then
				return false;
			elseif a.state == 0 and b.state == 2 then
				return true;
			elseif a.state == 1 and b.state ~= 1 then
				return true;
			elseif a.state == 2 and b.state ~= 2 then
				return false;
			end
			return a.id < b.id;
		end
	)
	self.itemList:setArrayData(msg.gear_list);
end

-- 活动操作处理
function Lua_CumulateRechargePanel:onItemOperate(data)
	if self.data == nil or data == nil then
		return;
	end
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	if data.state == 0 then
		DataCenter.funcPathUtil:gotoFunction(1003)
	elseif data.state == 1 then
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sReceiveReward(self.data.actIdx, data.id);
	end
end

function Lua_CumulateRechargePanel:onRuleClick(go)
	if self.data == nil then
		return;
	end

	local tipsData = { des = self.data.help_des, posX = 180, posY = -245 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end










Lua_CumulateRechargeItem = class("Lua_CumulateRechargeItem", Lua_ListCell);
function Lua_CumulateRechargeItem:ctor(p)
	self:superCall("ctor", p, "CumulateRechargeItem_skin");
end

function Lua_CumulateRechargeItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 432, 100, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_CumulateRechargeRewardItem, 100, 100, 1);
	self.rewardList:setCellSpacing(12, 0);
	self.rewardList:setRectPivot(3);
	self.rewardList:setLocation(-304, -15);
	self:setSubList(self.rewardList);

	self.btnFunc:addClickFuntion(self, self.onBtnFuncClick);
end

function Lua_CumulateRechargeItem:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_CumulateRechargeItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.titleTxt.text = data.title;

	self.rewardList:setArrayData(data.item_list);
	if data.item_list ~= nil then
		self.rewardList.canDrag = #data.item_list > 3;
	end

	if data.state == 2 then
		self.btnFunc:setEnable(false);
	elseif data.state == 1 then
		self.btnFunc:setEnable(true);
		self.btnFunc:setStyle(1);
		self.btnFunc.txt.colorStr = Lua_ColorDefine.transColorStr("8A5A37");
		self.btnFunc:setLangValue(202104);
	else
		self.btnFunc:setEnable(true);
		self.btnFunc:setStyle(3);
		self.btnFunc.txt.colorStr = Lua_ColorDefine.transColorStr("74604F");
		self.btnFunc:setLangValue(202103);
	end
	self.drawIcon:setEnable(data.state == 2);
	self:showRedDot(data.state == 1);
end

function Lua_CumulateRechargeItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(308, 23, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_CumulateRechargeItem:onPressClick(go)
	-- self.rewardList:onBoundClick();
end

function Lua_CumulateRechargeItem:onBtnFuncClick(go)
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("CUMULATE_RECHARGE_OPERATE", self.data);
end










Lua_CumulateRechargeRewardItem = class("Lua_CumulateRechargeRewardItem", Lua_ItemIconCell);
function Lua_CumulateRechargeRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon:setScale(0.8, 0.8);
end