-- 定制礼包
Lua_CustomGiftPanel = class("Lua_CustomGiftPanel", Lua_DisplayObject);
function Lua_CustomGiftPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_CustomGiftPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.giftList = Lua_DragList.new(self.content, 711, 810 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.giftList.tweenId = 2002;
	self.giftList:setListCell(Lua_CustomGiftItem, 711, 164, 1);
	self.giftList:setCellSpacing(0, 20);
	self.giftList:setRectAnchor(1);
	self.giftList:setLocation(0, -822 - self.adaptHeight / 2, 0);

	self.ruleBtn:addClickFuntion(self, self.onRuleClick);

	self:addLuaEvent("DRAW_CUSTOMGIFT_REWARD", self, self.customGiftEvent);
	self:addLuaEvent("UPDATE_CUSTOMGIFT_INFO", self, self.updateCustomGiftInfo);
end

function Lua_CustomGiftPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.giftList:setContentRect(711, 810 + adaptHeight);
	self.giftList:setLocation(0, -822 - adaptHeight / 2, 0);
end

function Lua_CustomGiftPanel:setData(actVo)
	self.actVo = actVo;
	self:startTimer();
	self:updateLeftTime();
end

function Lua_CustomGiftPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_CustomGiftPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_CustomGiftPanel:updateLeftTime()
	local time = self.actVo.residueTime;
	if time <= 0 then
		time = 0;
		self:endTimer();
	end
	self.leftTimeTxt.text = Lua_TimeTransform.transSeconds16(time, true, true, true);
end

function Lua_CustomGiftPanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.updateLeftTime);
	end
end

function Lua_CustomGiftPanel:onRuleClick(go)
	local tipData = { des = self.actVo.help_des, posX = 180, posY = -240 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_CustomGiftPanel:customGiftEvent(data)
	if DataCenter.backstageActData:checkActIsEnd(self.actVo) then
		return;
	end
	
	if data.eventType == 1 then
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sBuyCustomGift(self.actVo.actIdx, data.giftId);
	elseif data.eventType == 2 then
		Lua_WindowUtil.openWin("Lua_SelectCustomGiftWindow", Lua_WinParam.ACTION_OPEN, {actIdx = self.actVo.actIdx, giftInfo = data.giftInfo});
	end
end

function Lua_CustomGiftPanel:updateCustomGiftInfo()
	self.giftList:setArrayData(DataCenter.customGiftData.rewardArr);
end

function Lua_CustomGiftPanel:dispose()
	if self.giftList ~= nil then
		self.giftList:dispose();
		self.giftList = nil;
	end
	self.actVo = nil;
	self:endTimer();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_CustomGiftItem = class("Lua_CustomGiftItem", Lua_ListCell);
function Lua_CustomGiftItem:ctor(p)
	self:superCall("ctor", p, "CustomGiftItem_skin");
end

function Lua_CustomGiftItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 430, 96, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_CustomGiftRewardItem, 96, 96, 1);
	self.rewardList:setCellSpacing(7, 0);
	self.rewardList:setLocation(-321, -7, 0);
	self.rewardList:setRectPivot(3);
	self:setSubList(self.rewardList);

	self.buyBtn:addClickFuntion(self, self.onBuyBtnClick);
end

function Lua_CustomGiftItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local curCount = data.buy_limit - data.buy_times; -- 当前可购买数量
	self.tipsTxt.text = data.name;
	self.limitTimesTxt.text = LanUtil.formateStr(690000, curCount);

	self.rewardList.canDrag = data.showArr:getSize() > 4;
	self.rewardList:setArrayData(data.showArr);

	if data.choose_num > data.custom_num then
		self.buyBtn:setLangValue(690001);
	else
		if data.recharge_money <= 0 then
			self.buyBtn:setLangValue(690002);
		else
			self.buyBtn.label = LanUtil.formateStr(690003, data.recharge_money);
		end
	end
	self.buyBtn:setEnable(curCount > 0);
	self.sellOutIcon:setEnable(curCount <= 0);
	self.limitTimesTxt:setEnable(curCount > 0);
	self:showRedDot(data.recharge_money <= 0 and curCount > 0);
end

function Lua_CustomGiftItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(315, 16, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_CustomGiftItem:onBuyBtnClick()
	if self._data.choose_num > self._data.custom_num then
		Lua_MsgUtil.callFunc("DRAW_CUSTOMGIFT_REWARD", {eventType = 2, giftInfo = self._data.showArr[self._data.fixed_num + 1]});
	else
		if self._data.recharge_money <= 0 then
			Lua_MsgUtil.callFunc("DRAW_CUSTOMGIFT_REWARD", {eventType = 1, giftId = self._data.id});
		else
			local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(self._data.recharge_id);
			DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
				tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
		end
	end
end

function Lua_CustomGiftItem:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.rewardArr ~= nil then
		self.rewardArr:dispose();
		self.rewardArr:clear();
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end







--------------------------------------------------





Lua_CustomGiftRewardItem = class("Lua_CustomGiftRewardItem", Lua_ListCell);
function Lua_CustomGiftRewardItem:ctor(p)
	self:superCall("ctor", p, "CustomGiftRewardItem_skin");
end

function Lua_CustomGiftRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.giftIcon = Lua_ItemIcon.new(self.content);
	self.giftIcon:setSiblingIndex(2);
	self.giftIcon:setScale(0.7, 0.7);
	self.giftIcon:setLocation(-6, -6, 0);
end

function Lua_CustomGiftRewardItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local isShowItem = true;
	local isShowReset = false;
	if data.index <= data.fixed_num then
		self.giftIcon:setData(data.all_rewards[data.index]);
	else
		isShowItem = data.all_rewards[data.index] ~= 0;
		isShowReset = data.cur_count > 0 and data.all_rewards[data.index] ~= 0;
		if isShowItem then
			self.giftIcon:setData(data.all_rewards[data.index]);
		end
	end
	self.giftIcon:setEnable(isShowItem);
	self.reSetIcon:setEnable(isShowReset);
end

function Lua_CustomGiftRewardItem:onPressClick()
	if self._data == nil then
		return;
	end

	if self._data.index <= self._data.fixed_num then
		DataCenter.packUtil:showItemInfo(self.giftIcon.data);
	else
		if self._data.cur_count > 0 then
			Lua_MsgUtil.callFunc("DRAW_CUSTOMGIFT_REWARD", {eventType = 2, giftInfo = self._data});
		else
			DataCenter.packUtil:showItemInfo(self.giftIcon.data);
		end
	end
end

function Lua_CustomGiftRewardItem:dispose()
	if self.giftIcon ~= nil then
		self.giftIcon:dispose();
		self.giftIcon = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end