Lua_SelectCustomGiftWindow = class("Lua_SelectCustomGiftWindow", Lua_Window);
function Lua_SelectCustomGiftWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_SelectCustomGiftWindow";
	self.skinName = "SelectCustomGiftWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
	self.showCloseText = true;
	self.closeTextPosY = -420;
end

function Lua_SelectCustomGiftWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.selectGiftList = Lua_DragList.new(self.content, 520, 130, Lua_AxisDefine.Horizontal);
	self.selectGiftList.canDrag = false;
	self.selectGiftList:setListCell(Lua_SelectCustomGiftItem, 130, 130, 1);
	self.selectGiftList:setLocation(0, 168, 0);

	self.giftList = Lua_DragList.new(self.content, 520, 250, Lua_AxisDefine.Vertical);
	self.giftList:setListCell(Lua_SelectRewardItem, 130, 117, 4);
	self.giftList:setCellSpacing(0, 16);
	self.giftList:setLocation(0, -61, 0);

	self.sureBtn:addClickFuntion(self, self.onSureBtnClick);

	self:addLuaEvent("UPDATE_SELF_SELECT", self, self.updateSelfSelect);
	self:addLuaEvent("UPDATE_SHOE_SELECT", self, self.updateShowSelect);
end

function Lua_SelectCustomGiftWindow:showWin(param)
	self:superCall("showWin", param);

	self:updateSelectedList(param.giftInfo);
	self:updateShowSelect(param.giftInfo.index - param.giftInfo.fixed_num);
	self.selectGiftList:setSelected(param.giftInfo.index - param.giftInfo.fixed_num);
end

function Lua_SelectCustomGiftWindow:updateSelectedList(param)
	if self.selectedArr == nil then
		self.selectedArr = Array();

		local selectedTab = self.showData.giftInfo.cur_rewards;
		local vo;
		for i = 1, param.choose_num do
			vo = { index = i, tvo = selectedTab[i] };
			self.selectedArr:add(vo);
		end
		self.selectGiftList:setContentRect(130 * self.selectedArr:getSize(), 130);
		self.selectGiftList:setArrayData(self.selectedArr);
	end
end

-- 更新自己选择的奖励
function Lua_SelectCustomGiftWindow:updateSelfSelect(data)
	if self.selectedArr == nil then
		return;
	end
	self.giftIdx = self.giftIdx or 1;
	self.selectedArr[self.giftIdx].tvo = data;
	self.selectGiftList:setArrayData(self.selectedArr);
end

-- 更新显示的奖励
function Lua_SelectCustomGiftWindow:updateShowSelect(index)
	local tvo;
	if self.selectedArr ~= nil then
		tvo = self.selectedArr[index].tvo;
	end
	
	if self.giftIdx == index then
		DataCenter.packUtil:showItemInfo(tvo);
	end
	self.giftIdx = index;

	local selectedIdx = nil;
	local arr = Array();
	local customArr = self.showData.giftInfo.custom_rewards[index];
	local len = customArr:getSize();
	for i = 1, len do
		if tvo ~= nil and tvo.id == customArr[i].id and tvo.count == customArr[i].count then
			selectedIdx = i;
		end
		arr:add(customArr[i]);
	end
	self.giftList.canDrag = arr:getSize() > 8;
	self.giftList.curSelectedIdx = selectedIdx;
	self.giftList:setArrayData(arr);
end

function Lua_SelectCustomGiftWindow:onSureBtnClick(go)
	if self.selectedArr == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sDefineCustomGift(self.showData.actIdx, self.showData.giftInfo.id, self.selectedArr);
	self:hide();
end

function Lua_SelectCustomGiftWindow:dispose()
	if self.selectGiftList ~= nil then
		self.selectGiftList:dispose();
		self.selectGiftList = nil;
	end
	self:superCall("dispose");
end







--------------------------------------------------





Lua_SelectCustomGiftItem = class("Lua_SelectCustomGiftItem", Lua_ListCell);
function Lua_SelectCustomGiftItem:ctor(p)
	self:superCall("ctor", p, "SelectCustomGiftItem_skin");
end

function Lua_SelectCustomGiftItem:buildShowItem()
	self:superCall("buildShowItem");

	self.giftIcon = Lua_ItemIcon.new(self.content);
	self.giftIcon:setScale(0.9, 0.9);
	self.giftIcon:setSiblingIndex(2);
	self.giftIcon:setEnable(false);
end

function Lua_SelectCustomGiftItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end
	
	self.giftIcon:setData(data.tvo);
	self.giftIcon:setEnable(data.tvo ~= nil);
end

function Lua_SelectCustomGiftItem:onPressClick()
	Lua_MsgUtil.callFunc("UPDATE_SHOE_SELECT", self._data.index);
	return true;
end

function Lua_SelectCustomGiftItem:onSelectionChange(selectState)
	self:superCall("onSelectionChange", selectState);
	self.selectIcon:setEnable(selectState);
end

function Lua_SelectCustomGiftItem:dispose()
	if self.giftIcon ~= nil then
		self.giftIcon:dispose();
		self.giftIcon = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end







--------------------------------------------------





Lua_SelectRewardItem = class("Lua_SelectRewardItem", Lua_ListCell);
function Lua_SelectRewardItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_SelectRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.94, 0.94);
end

function Lua_SelectRewardItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end
	self.itemIcon:setData(data);
end

function Lua_SelectRewardItem:onPressClick()
	if self._data then
		Lua_MsgUtil.callFunc("UPDATE_SELF_SELECT", self._data);
		return true;
	end
end

function Lua_SelectRewardItem:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);
	self.itemIcon:setDrawMask(bSelect);
end

function Lua_SelectRewardItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end