-- 钻石商城
Lua_DiamondShopPanel = class("Lua_DiamondShopPanel", Lua_DisplayObject);
function Lua_DiamondShopPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_DiamondShopPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.infoBg:SetDimensions(702, 1000 + self.adaptHeight);

	self.giftList = Lua_DragList.new(self.content, 675, 800 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.giftList.tweenId = 2003;
	self.giftList:setListCell(Lua_diamondShopItem, 225, 304, 3);
	self.giftList:setCellSpacing(0, 8);
	self.giftList:setLocation(-5, -45);

	self:addLuaEvent("UPDATE_DIAMONDSHOP_INFO", self, self.updateDiamondShopInfo);
	self:addLuaEvent("ON_DIAMONDSHOP_ITEM_CLICK", self, self.onBuyGiftOperate);
	self:addLuaEvent("ON_DIAMONDSHOP_BUYGIFT", self, self.onRequestBuyGift);
end

function Lua_DiamondShopPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.infoBg:SetDimensions(702, 1000 + adaptHeight);
	self.giftList:setContentRect(675, 800 + adaptHeight);
end

function Lua_DiamondShopPanel:setData(actVo)
	self.actVo = actVo;
	self:startTimer();
	self:updateLeftTime();
end

function Lua_DiamondShopPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_DiamondShopPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_DiamondShopPanel:updateLeftTime()
	self.timeTxt.text = LanUtil.formateStr(769000, Lua_TimeTransform.transSeconds16(self.actVo.residueTime, true, true, true));
	if self.actVo.residueTime <= 0 then
		self.timeTxt:setLangValue(769001);
		self:endTimer();
	end
end

function Lua_DiamondShopPanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

function Lua_DiamondShopPanel:updateDiamondShopInfo(msg)
	if msg == nil then
		return;
	end

	table.sort(msg,
		function(a, b)
			local leftTimesA = a.num - a.value;
			local leftTimesB = b.num - b.value;
			if (leftTimesA > 0 and leftTimesB > 0) or (leftTimesA <= 0 and leftTimesB <= 0) then
				return a.id < b.id;
			else
				return leftTimesA > 0;
			end
		end
	);
	self.giftList:setArrayData(msg);
end

function Lua_DiamondShopPanel:onBuyGiftOperate(param)
	self:onDiamondShopOperate(1, param);
end

function Lua_DiamondShopPanel:onRequestBuyGift(param)
	self:onDiamondShopOperate(2, param);
end

function Lua_DiamondShopPanel:onDiamondShopOperate(operateType, param)
	if DataCenter.backstageActData:checkActIsEnd(self.actVo) then
		return;
	end

	if operateType == 1 then
		Lua_WindowUtil.openWin("Lua_DiamondShopBuyGiftWindow", Lua_WinParam.ACTION_OPEN, param);
	elseif operateType == 2 then
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sDiamondShopBuyGift(self.actVo.actIdx, param.data.id, param.buyNum);
	end
end

function Lua_DiamondShopPanel:dispose()
	if self.giftList ~= nil then
		self.giftList:dispose();
		self.giftList = nil;
	end
	self.actVo = nil;
	self:endTimer();
	self:superCall("dispose");
end










Lua_diamondShopItem = class("Lua_diamondShopItem", Lua_ListCell)
function Lua_diamondShopItem:ctor(p)
	self:superCall("ctor", p, "DiamondShopItem_skin");
end

function Lua_diamondShopItem:buildShowItem()
	self:superCall("buildShowItem");

	self.dragList = Lua_DragList.new(self.content, 200, 62, Lua_AxisDefine.Horizontal);
	self.dragList:setLocation(0, -25);
	self:setSubList(self.dragList);
end

function Lua_diamondShopItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local leftTimes = data.num - data.value;
	self.timesTxt.text = LanUtil.formateStr(769003, leftTimes);
	self.giftIcon:setAltas(data.icon_atlas, data.icon_sprite);
	self.giftIcon:resetSize();

	self.discountTxt_1.text = data.discount;
	if data.discount % 1 ~= 0 then -- 小数
		self.discountTxt_1.fontSize = 32;
		self.discountTxt_1:setLocation(8, 0, 0);
		self.discountTxt_2:setLocation(9, 0, 0);
	else
		self.discountTxt_1.fontSize = 54;
		self.discountTxt_1:setLocation(6, 1, 0);
		self.discountTxt_2:setLocation(7, -5, 0);
	end
	if data.price <= 0 then
		self.costTxt:setLangValue(769006);
	else
		self.costTxt.text = LanUtil.formateStr(769004, spliceIconStrById(data.money_type), data.price);
	end

	local arr = Array();
	if #data.items >= 4 then
		for i = 1, #data.items do
			arr:add({itemData = data.items[i], scale = 0.4, isGray = leftTimes <= 0});
		end
		self.dragList.canDrag = false; -- #data.items > 4
		self.dragList:setListCell(Lua_diamondShopRewardItem, 50, 50, 1);
		self.dragList:setContentRect(200, 50);
		self.dragList:setArrayData(arr);
	else
		for i = 1, #data.items do
			arr:add({itemData = data.items[i], scale = 0.5, isGray = leftTimes <= 0});
		end
		self.dragList.canDrag = false;
		self.dragList:setListCell(Lua_diamondShopRewardItem, 62, 62, 1);
		self.dragList:setContentRect(62 * #data.items, 62);
		self.dragList:setArrayData(arr);
	end
	self.bg:setGray(leftTimes <= 0);
	self.costTxt:setGray(leftTimes <= 0);
	self.giftIcon:setGray(leftTimes <= 0);
	self.selloutIcon:setEnable(leftTimes <= 0);
	self.discountObj:SetActive(data.price > 0);
	self:showRedDot(data.price <= 0 and leftTimes > 0);
end

function Lua_diamondShopItem:showRedDot(bShow)
	if bShow then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(85, 125);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_diamondShopItem:onPressClick()
	if self._data == nil or self._data.num - self._data.value <= 0 then
		return;
	end

	local winPos = LuaUtil.getTouchPosInverseObj(self.dragList.sub);
	for i = 1, self.dragList.showList:getSize() do
		if self.dragList.showList[i]:checkInBound(winPos.x, winPos.y) then
			return;
		end
	end
	Lua_MsgUtil.callFunc("ON_DIAMONDSHOP_ITEM_CLICK", self._data);
end

function Lua_diamondShopItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:onMouseDownHandle();
	end
end

function Lua_diamondShopItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		self.pressItem:onMouseUpHandle();
	end
end

function Lua_diamondShopItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.dragList.sub);
	for i = 1, self.dragList.showList:getSize() do
		if self.dragList.showList[i]:checkInBound(winPos.x, winPos.y) then
			return self.dragList.showList[i];
		end
	end
	return nil;
end

function Lua_diamondShopItem:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.pressItem = nil;
	self.data = nil;
	self:superCall("dispose");
end










Lua_diamondShopRewardItem = class("Lua_diamondShopRewardItem", Lua_ListCell);
function Lua_diamondShopRewardItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_diamondShopRewardItem:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon = Lua_ItemIcon.new(self.content);
end

function Lua_diamondShopRewardItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	if self.itemVo == nil then
		self.itemVo = Lua_ToolVo.createToolVo(data.itemData.id);
	else
		self.itemVo:setData(data.itemData.id);
	end
	self.itemVo:fromServer(data.itemData);
	self.itemIcon:setData(self.itemVo);
	self.itemIcon:setScale(data.scale, data.scale);
	self.itemIcon:setGray(data.isGray);
end

function Lua_diamondShopRewardItem:onPressClick()
	-- if self._data.isGray then
	-- 	return;
	-- end
	self.itemIcon:onItemClick();
end

function Lua_diamondShopRewardItem:onMouseDownHandle()
	self.itemIcon:setScale(self._data.scale * 0.95, self._data.scale * 0.95);
end

function Lua_diamondShopRewardItem:onMouseUpHandle()
	self.itemIcon:setScale(self._data.scale, self._data.scale);
end

function Lua_diamondShopRewardItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self._data = nil;
	self.itemVo = nil;
	self:superCall("dispose");
end