-- 欧皇召唤
Lua_EuropeanRecruitMainWindow = class("Lua_EuropeanRecruitMainWindow", Lua_Window);
function Lua_EuropeanRecruitMainWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_EuropeanRecruitMainWindow";
	self.skinName = "EuropeanRecruitMainWindow_skin";
	self.showCloseText = true;
	self.closeTextPosY = -592;
	self.showBlackMask = true;
	self.isClickClose = true;

	self:preLoadSelfRes();
end

-- 预加载资源
function Lua_EuropeanRecruitMainWindow:preLoadSelfRes()
	self.bg_1_path = "/images/activities/xui_ohzh_widget_1.png";
	self.bg_2_path = "/images/activities/xui_ohzh_widget_2.png";
	self:addPreLoadRes(self.bg_1_path, Lua_LoadFileType.IMG);
	self:addPreLoadRes(self.bg_2_path, Lua_LoadFileType.IMG);
end

function Lua_EuropeanRecruitMainWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.bg_1:setUrl(self.bg_1_path);
	self.bg_2:setUrl(self.bg_2_path);
	self.bg_3:setUrl("/images/activities/xui_ohzh_widget_3.png");
	self.recruitBtn:setLangValue(163057);

	self.activeId = DataCenter.europeanRecruitData:getEuropeanRecruitActId();
	self.actVo = DataCenter.backstageActData:getActVoByIdx(self.activeId);
	self.tipDesc = self.actVo ~= nil and self.actVo.help_des;

	self.tipSp:addClickFuntion(self, self.onTipSpClick);
	self.recordSp:addClickFuntion(self, self.onClickRecordSp);
	self.invitateSp:addClickFuntion(self, self.onClickInvitateSp);
	self.recruitBtn:addClickFuntion(self, self.onClickRecruitBtn);
	self:addLuaEvent("UPDATE_EUROPEANRECRUIT_MAINWININFO", self, self.updateEuropeanRecruitInfo);

	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sActivityInfo(self.activeId);
end

function Lua_EuropeanRecruitMainWindow:dispose()
	self.actVo = nil;

	if self.recruitRedPoint ~= nil then
		self.recruitRedPoint:dispose();
		self.recruitRedPoint = nil;
	end
	if self.recordRedPoint ~= nil then
		self.recordRedPoint:dispose();
		self.recordRedPoint = nil;
	end
	self:superCall("dispose");
end

function Lua_EuropeanRecruitMainWindow:updateEuropeanRecruitInfo()
	self.activeState = DataCenter.europeanRecruitData:checkLevelUnlock();
	self.btnObj:SetActive(self.activeState == true);
	self:updateInvitationPersonNum();	 
	self:updateSaveRecordNum();
	self:updateCurReceivedNum();

	local showRecord;
	local showRecruit;
	local actRedPointState = DataCenter.redPointData:getRedPointStateById(tostring(self.activeId));
	if actRedPointState then
		if DataCenter.europeanRecruitData.residueDraw > 0 then
			showRecruit = true;
		else
			showRecord = true;
		end
	end
	
	self:showRecruitRedPoint(showRecruit == true);
	self:showRecordRedPoint(showRecord == true);
end

function Lua_EuropeanRecruitMainWindow:checkClickValid()
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.5 then
		return;
	end
	self.clickTime = getTime();

	if self.actVo == nil then
		self.actVo = DataCenter.backstageActData:getActVoByIdx(self.activeId);
	end

	if DataCenter.backstageActData:checkActIsEnd(self.actVo) then
		return;
	end

	return true;
end

function Lua_EuropeanRecruitMainWindow:onClickInvitateSp()
	if self:checkClickValid() ~= true then
		return;
	end
	
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sEuropeanRecruitInvitationInfo(self.activeId, 1)
end

function Lua_EuropeanRecruitMainWindow:onClickRecordSp()
	if self:checkClickValid() ~= true then
		return;
	end

	DataCenter.europeanRecruitData.recordType = nil;
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sEuropeanRecruitRecordInfo(self.activeId, 1);
end

function Lua_EuropeanRecruitMainWindow:onTipSpClick(go)
	if self:checkClickValid() ~= true then
		return;
	end

	local tipData = { 
		des = self.tipDesc, 
		posX = 23, 
		posY = -564,
		maxWidth = 434,
		maxHeight = 465 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_EuropeanRecruitMainWindow:onClickRecruitBtn()
	if self.activeState ~= true then
		local unlockLevelId = DataCenter.europeanRecruitData.unlockLevelId;
		local str = getConfig("mainline_game_level", unlockLevelId, "name") or "";
		str = LanUtil.formateStr(163056, str);
		OperateAlert.show(str);
		return;
	end

	if self:checkClickValid() ~= true then
		return;
	end

	local bReceived = DataCenter.europeanRecruitData:checkReceived();
	if bReceived then
		OperateAlert.showLangValue(163061);
		return;
	end

	local residueDraw = DataCenter.europeanRecruitData.residueDraw;
	if residueDraw <= 0 then
		self.recruitBtn:setGray(residueDraw <= 0);
		OperateAlert.showLangValue(163000);
		return;
	end

	DataCenter.europeanRecruitData:checkRecordData();
	Lua_ProxyManager.getProxy("Lua_RecruitProxy"):sRecruitStar(Lua_RecruitData.EUROPEANRECRUIT, 0);
end

function Lua_EuropeanRecruitMainWindow:updateInvitationPersonNum()
	local totalNum = DataCenter.europeanRecruitData.maxInvitationPersonNum or 0;
	local residueNum = DataCenter.europeanRecruitData.invitationPersonNum or 0;
	self.personNumTxt.text = LanUtil.formateStr(163001, residueNum, totalNum);
end

function Lua_EuropeanRecruitMainWindow:updateSaveRecordNum()
	local totalNum = DataCenter.europeanRecruitData.maxSaveRecordNum or 0;
	local residueNum = DataCenter.europeanRecruitData.saveRecordNum or 0;
	self.recordNumTxt.text = LanUtil.formateStr(163002, residueNum, totalNum);
end

function Lua_EuropeanRecruitMainWindow:updateCurReceivedNum()
	local totalNum = DataCenter.europeanRecruitData.maxReceivedTime or 0;
	local residueNum = DataCenter.europeanRecruitData.receivedTime or 0;
	local str;
	if residueNum <= 0 then
		str = 163003;
	else
		str = 163004;
	end
	self.curReceivedNumTxt.text = LanUtil.formateStr(str, residueNum, totalNum);

	local bGray = self.activeState ~= true and true or false;
	if not bGray then
		bGray = DataCenter.europeanRecruitData:checkReceived();
		if not bGray then
			bGray = DataCenter.europeanRecruitData.residueDraw <= 0;
		end
	end
	self.recruitBtn:setGray(bGray);
end

function Lua_EuropeanRecruitMainWindow:showRecruitRedPoint(value)
	if value then
		if self.recruitRedPoint == nil then
			self.recruitRedPoint = Lua_RedPointIcon.new(self.content)
			self.recruitRedPoint:setLocation(109, -446)
			self.recruitRedPoint:createRedPointImg();
		end
		self.recruitRedPoint:updateRedPointShow(true)
	else
		if self.recruitRedPoint then
			self.recruitRedPoint:updateRedPointShow(false)
		end
	end
end

function Lua_EuropeanRecruitMainWindow:showRecordRedPoint(value)
	if value then
		if self.recordRedPoint == nil then
			self.recordRedPoint = Lua_RedPointIcon.new(self.content)
			self.recordRedPoint:setLocation(312, -43)
			self.recordRedPoint:createRedPointImg();
		end
		self.recordRedPoint:updateRedPointShow(true)
	else
		if self.recordRedPoint then
			self.recordRedPoint:updateRedPointShow(false)
		end
	end
end