-- 助力对象
Lua_EuropeanRecruitShareWindow = class("Lua_EuropeanRecruitShareWindow", Lua_Window);
function Lua_EuropeanRecruitShareWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_EuropeanRecruitShareWindow";
	self.skinName = "EuropeanRecruitShareWindow_skin";
	self.showWinBg = true;
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_EuropeanRecruitShareWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setLocation(-234, 382, 0)

	self.helpBtn:setLangValue(163026);
	self.helpBtn:addClickFuntion(self, self.onClickHelpBtn);
end

function Lua_EuropeanRecruitShareWindow:dispose()
	self.actVo = nil;
	self.helpPlayIdDic = nil;
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self:superCall("dispose");
end

function Lua_EuropeanRecruitShareWindow:showWin(param)
	self:superCall("showWin", param);

	local playerInfo = param.show_role;
	self.playerId = nil;
	if playerInfo ~= nil then
		self.playerId = tonumber(playerInfo.id);
		self.avatarItem:setRoleId(self.playerId);
		self.avatarItem:setRoleDressUp(playerInfo.dress_info, true)
		self.avatarItem:setRoleLevel2(playerInfo.level)

		self.descTxt.text = LanUtil.formateStr(163027, playerInfo.server_prev, playerInfo.name);
	end

	self.descTxt_1:setLangValue(163028);
	self.recruitTxt.text = LanUtil.formateStr(163008, param.add_times);

	self:updateInvitationPersonNum();
	self:updateResidueNum();
	self:updateHelpPlayers();
end

function Lua_EuropeanRecruitShareWindow:updateInvitationPersonNum()
	local totalNum = self.showData.max_help or 0;
	local residueNum = self.showData.curr_help or 0;
	self.personNumTxt.text = LanUtil.formateStr(163009, residueNum, totalNum);
end

function Lua_EuropeanRecruitShareWindow:updateResidueNum()
	-- local totalNum = 5; -- DataCenter.europeanRecruitData
	local residueNum = self.showData.help_times or 0;
	self.helpBtn:setGray(residueNum <= 0);
	self.residueNumTxt.text = LanUtil.formateStr(163029, residueNum);
end

function Lua_EuropeanRecruitShareWindow:checkClickValid()
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.5 then
		return;
	end
	self.clickTime = getTime();

	if self.actVo == nil then
		local activeId = DataCenter.europeanRecruitData:getEuropeanRecruitActId();
		self.actVo = DataCenter.backstageActData:getActVoByIdx(activeId);
	end

	if DataCenter.backstageActData:checkActIsEnd(self.actVo) then
		return;
	end

	return true;
end

function Lua_EuropeanRecruitShareWindow:onClickHelpBtn()
	local close_tick = tonumber(self.showData.close_tick) or 0;
	if close_tick - DataCenter.roleData.serverTime <= 0 then
		OperateAlert.showLangValue(163030);
		return;
	end

	local residueNum = self.showData.help_times or 0;
	if residueNum <= 0 then
		OperateAlert.showLangValue(163031);
		return;
	end

	if self:checkClickValid() ~= true then
		return;
	end

	local playerId = DataCenter.roleData.roleId;
	if self.helpPlayIdDic ~= nil and self.helpPlayIdDic[playerId] then
		OperateAlert.showLangValue(163032);
		return;
	end

	local totalNum = self.showData.max_help or 0;
	local curr_help = self.showData.curr_help or 0;
	if totalNum <= curr_help then
		OperateAlert.showLangValue(163033);
	else
		local activeId = DataCenter.europeanRecruitData:getEuropeanRecruitActId();
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sEuropeanRecruitAcceptInvitation(activeId, self.playerId, self.showData.show_role.server_flag);
	end
end

function Lua_EuropeanRecruitShareWindow:updateHelpPlayers()
	if self.helpPlayers == nil then
		self.helpPlayers = {};
	end

	self.helpPlayIdDic = {};

	local item;
	local obj = self.showData.helper_list or {};
	local count = 5;
	local posList = {
		{-8, 245},
		{201, 97},
		{117, -140},
		{-133, -138},
		{-208, 97}
	};

	local playerId;
	local posX, posY;
	for i = 1, count do
		item = self.helpPlayers[i];
		if item == nil then
			item = Lua_EuropeanRecruitShareItem.new(self.content);
			self.helpPlayers[i] = item;
		end

		posX = posList ~= nil and posList[i] ~= nil and posList[i][1] or 0;
		posY = posList ~= nil and posList[i] ~= nil and posList[i][2] or 0;
		item:setLocation(posX, posY);
		item:setData(obj[i]);

		if obj[i] ~= nil then
			playerId = tonumber(obj[i].id);
			self.helpPlayIdDic[playerId] = true;
		end
	end
end




















----------------------------------
Lua_EuropeanRecruitShareItem = class("Lua_EuropeanRecruitShareItem", Lua_DisplayObject);
function Lua_EuropeanRecruitShareItem:ctor(p)
	self:superCall("ctor", p, "EuropeanRecruitShareItem_skin");
end

function Lua_EuropeanRecruitShareItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_EuropeanRecruitShareItem:dispose()
	self.data = nil;
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end

	self:superCall("dispose");
end

function Lua_EuropeanRecruitShareItem:setData(data)
	self.data = data;

	self.addSp:setEnable(data == nil);
	self.selectedSp:setEnable(data ~= nil);
	self:showAvatarItem(data);
end

function Lua_EuropeanRecruitShareItem:showAvatarItem(playerInfo)
	if playerInfo == nil then
		if self.avatarItem ~= nil then
			self.avatarItem:setEnable(false);
		end
	else
		if self.avatarItem == nil then
			self.avatarItem = Lua_AvatarItem.new(self.content)
			self.avatarItem:setScale(0.82, 0.82, 1)
			self.avatarItem:setSiblingIndex(self.selectedSp.siblingIndex);
		end

		self.avatarItem:setRoleId(playerInfo.id)
		self.avatarItem:setRoleDressUp(playerInfo.dress_info, true)
		self.avatarItem:setRoleLevel(playerInfo.level);
	end
end