-- 英雄试炼
Lua_HeroTrialPanel = class("Lua_HeroTrialPanel", Lua_DisplayObject)
function Lua_HeroTrialPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_HeroTrialPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rankItemArr = Array();
	self.listBg:SetDimensions(720, 611 + self.adaptHeight);
	self.barImg:SetDimensions(0, 16);

	self.dragList = Lua_DragList.new(self.content, 702, 750 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.dragList.tweenId = 2002;
	self.dragList:setListCell(Lua_HeroTrialStageItem, 702, 166, 1);
	self.dragList:setCellSpacing(0, 10);
	self.dragList:setLocation(0, -190);

	self.checkRankTxt:resetSize();
	self.checkRankTxt:addClickFuntion(self, self.onRankBtnClick);
	self.ruleBtn:addClickFuntion(self, self.onRuleClick);
	self.buffLevelBg:addClickFuntion(self, self.onBuffBtnClick);

	self:addLuaEvent("UPDATE_HEROTRIAL_INFO", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_RANK_INFO", self, self.updateRankInfo);
	self:addLuaEvent("HEROTRIAL_CHALLENGE", self, self.showLineupWindow);
	self:addLuaEvent("SEND_HEROTRIAL_RANKREWARD", self, self.sendRankReward);
	self:addLuaEvent("FIGHTPLAY_ENTER", self, self.updateShowRewardInfo);
	self:addLuaEvent("FIGHTPLAY_COMPLETE", self, self.updateShowRewardInfo);
	Lua_ProxyManager.getProxy("Lua_RankProxy"):sGetRankInfo(Lua_RankData.MONSTER_TYPE, 0);
end

function Lua_HeroTrialPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.dragList:setContentRect(702, 750 + adaptHeight);
	self.listBg:SetDimensions(720, 611 + adaptHeight);
end

function Lua_HeroTrialPanel:setData(actVo)
	if actVo == nil then
		return;
	end
	self.actVo = actVo;
	self:startTimer();
end

function Lua_HeroTrialPanel:startTimer()
	self:updateTime();
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("OnHeroTrialTimer", 1, self, self.updateTime);
	end
end

function Lua_HeroTrialPanel:updateTime()
	local time = self.actVo.residueTime;
	self.timeTxt.text = LanUtil.formateStr(750001, Lua_TimeTransform.transSeconds16(time, true, true, true));
	if time <= 0 then
		self.timeTxt:setLangValue(750000);
		self:stopTimer();
	end
end

function Lua_HeroTrialPanel:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.updateTime);
	end
end

function Lua_HeroTrialPanel:updateShowInfo()
	self:updateShowRewardInfo();
	self:updateCount();
	self:updateBuff();
end

function Lua_HeroTrialPanel:updateShowRewardInfo()
	local levelRecordId = DataCenter.fightData:getRecordIdByTemplateId(Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_LEVEL);
	local endlessRecordId = DataCenter.fightData:getRecordIdByTemplateId(Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_ENDLESS);
	if levelRecordId <= 0 and endlessRecordId <= 0 then
		DataCenter.newHeroActData.curFightLevelId = nil;
	else
		if self.levelId then
			DataCenter.newHeroActData.curFightLevelId = self.levelId;
		end
	end
	self:updateList();
end

function Lua_HeroTrialPanel:updateList()
	self.dragList:setArrayData(DataCenter.newHeroActData.stageInfo);
end

function Lua_HeroTrialPanel:updateCount()
	local curCount = DataCenter.newHeroActData.curCount;
	local totalCount = DataCenter.newHeroActData.totalCount;
	self.countTxt.text = LanUtil.formateStr(750002, curCount, totalCount);
end

function Lua_HeroTrialPanel:updateBuff()
	local buffInfo = DataCenter.newHeroActData.buffInfo;
	if buffInfo == nil then
		return;
	end

	self.levelTxt.text = buffInfo.buff_lvl;
	local showValue = buffInfo.cur_exe > buffInfo.exe_limit and buffInfo.exe_limit or buffInfo.cur_exe;
	local maxValue = buffInfo.exe_limit;
	self.barImg:SetDimensions(98 * showValue / maxValue, 16);
	self.barText.text = LanUtil.formateStr("{1}/{2}", showValue, maxValue);
end

function Lua_HeroTrialPanel:updateRankInfo(msg)
	if msg == nil then
		return;
	end
	
	-- table.sort( msg.rank_list, function(a, b) return a.rank < b.rank end);
	local item;
	for i = 1, 3 do
		item = self.rankItemArr[i];
		if item == nil then
			item = Lua_HeroTrialMiniRankItem.new(self.heroTrial_uitweenObj_1);
			item:setRectAnchor(1);
			item:setLocation(-97, 59 - (i - 1) * 40);
			self.rankItemArr:add(item);
		end
		item:setData(i, msg.rank_list[i]);
	end
end

function Lua_HeroTrialPanel:onRankBtnClick()
	if DataCenter.backstageActData:checkActIsEnd(self.actVo) then
		return;
	end
	Lua_WindowUtil.openWin("Lua_HeroTrialRankWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_HeroTrialPanel:onRuleClick()
	local tipsData = {des = self.actVo.help_des, posX = 175, posY = -576};
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_HeroTrialPanel:onBuffBtnClick()
	Lua_WindowUtil.openWin("Lua_HeroTrialBuffInfoWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_HeroTrialPanel:showLineupWindow(data)
	if DataCenter.backstageActData:checkActIsEnd(self.actVo) then
		return;
	end

	local levelRecordId = DataCenter.fightData:getRecordIdByTemplateId(Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_LEVEL);
	local endlessRecordId = DataCenter.fightData:getRecordIdByTemplateId(Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_ENDLESS);
	local templateId = data.special == 1 and Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_ENDLESS or Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_LEVEL;
	if levelRecordId > 0 or endlessRecordId > 0 then
		if data.id ~= DataCenter.newHeroActData.curFightLevelId then
			OperateAlert.showLangValue(750020);
		else
			local recordId = DataCenter.fightData:getRecordIdByTemplateId(templateId);
			DataCenter.fightData:showFightToStageByRid(recordId);
		end
	else
		local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(templateId);
		if data.special == 1 then
			self.levelId = data.id;
			DataCenter.preLoadData:preShowScene("Lua_FightLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, data, sceneId, 0);
		else
			local count = DataCenter.newHeroActData.curCount;
			local state = count <= 0 and data.win_flag == 1;
			if state then
				OperateAlert.showLangValue(750003);
			else
				self.levelId = data.id;
				DataCenter.preLoadData:preShowScene("Lua_FightLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, data, sceneId, 0);
			end
		end
	end
end

function Lua_HeroTrialPanel:onSceneShow(param)
	local config = Lua_MonsterPlayerConfigData.getConfigData(param.monster_id);
	if config == nil then
		DataCenter.preLoadData:removeBySign("Lua_FightLineupWindow", self, self.onSceneShow);
		LogManager.LogError("no tb_monster_player/tb_monster_player_index config id : " .. param.monster_id, false);
		return;
	end

	local templateId = param.special == 1 and Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_ENDLESS or Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_LEVEL;
	DataCenter.newHeroActData.heroTrialMonsterId = param.monster_id;
	local list = {
		template_id = templateId,
		monster_player_id = param.monster_id,
		stage_id = param.id
	};
	Lua_WindowUtil.openWin("Lua_FightLineupWindow", Lua_WinParam.ACTION_OPEN, list);
end

function Lua_HeroTrialPanel:sendRankReward()
	Lua_ProxyManager.getProxy("Lua_NewHeroActivityProxy"):sHeroTrialRankReward(self.actVo.actIdx);
end

function Lua_HeroTrialPanel:dispose()
	if self.rankItemArr ~= nil then
		self.rankItemArr:dispose();
		self.rankItemArr:clear();
		self.rankItemArr = nil;
	end
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	self.actVo = nil;
	DataCenter.preLoadData:removeBySign("Lua_FightLineupWindow", self, self.onSceneShow);
	self:stopTimer();
	self:superCall("dispose");
end










Lua_HeroTrialStageItem = class("Lua_HeroTrialStageItem", Lua_ListCell)
function Lua_HeroTrialStageItem:ctor(p)
	self:superCall("ctor", p, "HeroTrialStageItem_skin");
end

function Lua_HeroTrialStageItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemVoArr = Array();

	self.itemList = Lua_DragList.new(self.content, 300, 93, Lua_AxisDefine.Horizontal);
	self.itemList:setListCell(Lua_HeroTrialStageRewardCell, 93, 93, 1);
	self.itemList:setRectPivot(3);
	self.itemList:setLocation(-214, -16);
	self.itemList:setSiblingIndex(self.maskBg.siblingIndex);
	self:setSubList(self.itemList);

	self.challengeBtn:addClickFuntion(self, self.onChallengeBtnClick);
end

function Lua_HeroTrialStageItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local arrLen = self.itemVoArr:getSize();
	local dataLen = #data.reward;
	local maxLen = arrLen > dataLen and arrLen or dataLen;
	local vo;
	for i = 1, maxLen do
		vo = self.itemVoArr[i];
		if i > dataLen then
			if vo ~= nil then
				self.itemVoArr:removeItem(vo);
			end
		else
			if vo == nil then
				vo = Lua_ToolVo.createToolVo(data.reward[i].key, data.reward[i].value);
				self.itemVoArr:add(vo);
			else
				vo:setData(data.reward[i].key, data.reward[i].value);
			end
		end
	end
	self.itemList.canDrag = dataLen >= 4 and data.state == 1;
	self.itemList:setArrayData(self.itemVoArr);

	if data.state == 0 then -- 关卡状态：0未解锁 1可挑战
		self.titleTxt.text = LanUtil.formateStr(750022, data.chaper_title);
	else
		if data.win_flag == 1 then -- 首通标识：1通关 0未通关
			if data.special == 1 then -- 是否为特殊关卡（无限挑战关卡）0否，1是
				self.itemList:setArrayData(nil);
				self.tipTxt:setLangValue(750017); -- 可无限重复挑战，无挑战奖励
			end
			self.titleTxt:setLangValue(750005); -- 挑战奖励
		else
			self.titleTxt:setLangValue(750004); -- 首通奖励
		end
	end
	self.tipTxt:setEnable(data.state ~= 0 and data.win_flag == 1 and data.special == 1);

	if data.special == 0 then
		self.chapterTxt:SetDimensions(100, 31);
		self.scoreTxt.text = LanUtil.formateStr(750006, data.score, data.score_limit);
	else
		self.chapterTxt:SetDimensions(77, 31);
		self.scoreTxt.text = LanUtil.formateStr(750007, data.score);
	end
	self.chapterTxt.text = data.title;
	self.maskBg:setEnable(data.state ~= 1);
	self.scoreTxt:setEnable(data.state == 1);

	self.challengeBtn:setMouseEnable(data.state == 1);
	if data.id == DataCenter.newHeroActData.curFightLevelId then
		self.challengeBtn:setLangValue(750019);
	else
		self.challengeBtn:setLangValue(750018);
	end
	self:showEffect(data.id == DataCenter.newHeroActData.curFightLevelId);
	self:showRedDot(data.red_state == 1); -- 红点状态：1开启 2关闭
end

function Lua_HeroTrialStageItem:showEffect(value)
	if value then
		if self.btnEff == nil then
			self.btnEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_ty_zdbs_0101", "ui_ty_zdbs_0101", 12, 165);
			self.btnEff:setScale(0.5, 0.5, 0.5);
			self.btnEff:setLocation(302, -10);
		end
		self.btnEff:setEnable(false);
		self.btnEff:setEnable(true);
	else
		if self.btnEff then
			self.btnEff:setEnable(false);
		end
	end
end

function Lua_HeroTrialStageItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setScale(0.9, 0.9);
			self.redPoint:setLocation(307, -2, 0);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_HeroTrialStageItem:onChallengeBtnClick()
	Lua_MsgUtil.callFunc("HEROTRIAL_CHALLENGE", self.data);
end

function Lua_HeroTrialStageItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.itemList.sub);
	for i = 1, self.itemList.showList:getSize() do
		if self.itemList.showList[i]:checkInBound(winPos.x, winPos.y) then
			return self.itemList.showList[i];
		end
	end
	return nil;
end

function Lua_HeroTrialStageItem:onMouseDownHandle()
	if #self.data.reward > 3 then
		return;
	end

	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:onMouseDownHandle();
	end
end

function Lua_HeroTrialStageItem:onMouseUpHandle()
	if #self.data.reward > 3 then
		return;
	end

	if self.pressItem ~= nil then
		self.pressItem:onMouseUpHandle();
	end
end

function Lua_HeroTrialStageItem:dispose()
	self.pressItem = nil;
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.itemVoArr ~= nil then
		self.itemVoArr:dispose();
		self.itemVoArr:clear();
		self.itemVoArr = nil;
	end
	self:superCall("dispose");
end










Lua_HeroTrialStageRewardCell = class("Lua_HeroTrialStageRewardCell", Lua_ItemIconCell)
function Lua_HeroTrialStageRewardCell:ctor(p)
	self:superCall("ctor", p);
end

function Lua_HeroTrialStageRewardCell:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon:setScale(0.75, 0.75);
end

function Lua_HeroTrialStageRewardCell:onMouseDownHandle()
	self.itemIcon:setScale(0.7, 0.7);
end

function Lua_HeroTrialStageRewardCell:onMouseUpHandle()
	self.itemIcon:setScale(0.75, 0.75);
end

function Lua_HeroTrialStageRewardCell:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:superCall("dispose");
end










Lua_HeroTrialMiniRankItem = class("Lua_HeroTrialMiniRankItem", Lua_DisplayObject);
function Lua_HeroTrialMiniRankItem:ctor(p)
	self:superCall("ctor", p, "HeroTrialMiniRankItem_skin");
end

function Lua_HeroTrialMiniRankItem:setData(rank, data)
	self.rankIcon:setAltas("new_hero_atlas_1", "xui_boos_label_"..rank);
	self.rankIcon:resetSize();

	if data == nil then
		self.nameTxt:setLangValue(750008);
		self.scoreTxt:setEnable(false);
	else
		self.nameTxt.text = data.player_show.name;
		self.scoreTxt.text = data.value;
		self.scoreTxt:setEnable(true);
	end
end