-- 英雄试炼排行榜
Lua_HeroTrialRankPanel = class("Lua_HeroTrialRankPanel", Lua_DisplayObject);
function Lua_HeroTrialRankPanel:ctor(p)
	self:superCall("ctor", p, "HeroTrialRankPanel_skin");
end

function Lua_HeroTrialRankPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.topRankArr = Array();
	self.rankArr = Array();

	self.itemList = Lua_DragList.new(self.content, 700, 540 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_HeroTrialRankItem, 688, 125, 1);
	self.itemList:setLocation(0, -172, 0);
	self.itemList:setCellSpacing(0, 10);
	self.itemList.callBackOwner = self;
	self.itemList.turnPageCallBack = self.turePage;

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setRectAnchor(7);
	self.avatarItem:setLocation(-148, 191, 0);
	self.avatarItem:setScale(0.7, 0.7);
	self.avatarItem:setCanClick(true);

	self.myNameTxt.text = DataCenter.roleData.name;

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setRectAnchor(7);
	self.rankNum:setLocation(-270, 186, 0);
	self.rankNum.pivot = 0;
	self.rankNum.numOffsetX = -2;
	self.rankNum.numAtlas = "number";
	self.rankNum.preStr = "xui_phb_number_";

	self:addLuaEvent("UPDATE_RANK_INFO", self, self.updateShowInfo);
	self.recordSp:addClickFuntion(self, self.onMaxFightInfoClick);
	self:turePage(0);
end

function Lua_HeroTrialRankPanel:updateShowInfo(msg)
	if msg == nil then
		return;
	end

	local myself_rank = msg.self_rank;
	local rank_list = msg.rank_list;
	if myself_rank == nil or rank_list == nil then
		return;
	end
    self.hurt_collect = myself_rank.hurt_collect;
	self.myScoreTxt.text = LanUtil.formateStr(750010, myself_rank.value);
	self.avatarItem:setRoleId(myself_rank.player_show.id);
	self.avatarItem:setRoleDressUp(myself_rank.player_show.dress_info, true);
	self.avatarItem:setRoleLevel2(myself_rank.player_show.level);

	if myself_rank.rank == 0 then
		self.myNoneRankSp:setEnable(true);
		self.recordSp:setEnable(false);
		self.avatarItem:setEnable(false);
		self.myScoreTxt:setEnable(false);
		self.myNameTxt:setEnable(false);
		self.myRankSplitSp:setEnable(false);
		self.rankNum.num = nil;
	else
		self.myNoneRankSp:setEnable(false);
		self.recordSp:setEnable(true);
		self.avatarItem:setEnable(true);
		self.myScoreTxt:setEnable(true);
		self.myNameTxt:setEnable(true);
		self.myRankSplitSp:setEnable(true);
		self.rankNum.num = myself_rank.rank;
	end

	local posDic = {{1, -366}, {-235, -366}, {236, -366}};
	local item;
	for i = 1, 3 do
		item = self.topRankArr[i];
		if item == nil then
			item = Lua_HeroTrialTopRankItem.new(self.content);
			item:setRectAnchor(1);
			self.topRankArr:add(item);
		end
		item:setLocation(posDic[i][1], posDic[i][2]);
		item:setData(i, rank_list[i]);
	end

	for i = 4, #rank_list do
		self.rankArr:add(rank_list[i]);
	end
	self.itemList.isPageEnd = msg.is_end;
	self.itemList:setArrayData(self.rankArr);
    self.itemList:setEnable(#rank_list >= 4);
	self.noRankTxt:setEnable(#rank_list < 4);
	self.catImg:setEnable(#rank_list < 4);
end

function Lua_HeroTrialRankPanel:onMaxFightInfoClick()
	Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.hurt_collect);
end

function Lua_HeroTrialRankPanel:turePage(page)
	page = page or 1;
	Lua_ProxyManager.getProxy("Lua_RankProxy"):sGetRankInfo(Lua_RankData.MONSTER_TYPE, page);
end

function Lua_HeroTrialRankPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.itemList:setContentRect(700, 540 + adaptHeight);
end

function Lua_HeroTrialRankPanel:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	if self.rankArr ~= nil then
		self.rankArr:dispose();
		self.rankArr:clear();
		self.rankArr = nil;
	end
	if self.topRankArr ~= nil then
		self.topRankArr:dispose();
		self.topRankArr:clear();
		self.topRankArr = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_HeroTrialTopRankItem = class("Lua_HeroTrialTopRankItem", Lua_DisplayObject);
function Lua_HeroTrialTopRankItem:ctor(p)
	self:superCall("ctor", p, "HeroTrialRankTopItem_skin");
end

function Lua_HeroTrialTopRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);

	self.recordSp:addClickFuntion(self, self.onMaxFightInfoClick);
end

function Lua_HeroTrialTopRankItem:setData(rank, data)
	self.data = data;
	self.bg:setAltas("rank_altas", "xui_phb_bg_"..(rank + 1))

	local iconPosX = 16;
	if data == nil then
		self.nameTxt:setLangValue(510012);
		self.noRankHeadImg:setEnable(true);
		self.scoreTxt:setEnable(false);
		self.recordSp:setEnable(false);
	else
		self.avatarItem:setRoleDressUp(data.player_show.dress_info, true);
		self.avatarItem:setRoleLevel2(data.player_show.level);
		self.avatarItem:setRoleId(data.player_show.id);
		self.noRankHeadImg:setEnable(false);
        
		self.nameTxt.text = data.player_show.name;
		self.scoreTxt.text = data.value;
		self.scoreTxt:resetSize();
		local newWidth = self.scoreTxt.width;
		iconPosX = iconPosX + (newWidth - 16)/2;
	end

	if rank == 1 then
		self.avatarItem:setScale(0.9, 0.9);
		if data ~= nil then
			self.nameTxt:setLocation(0, -26);
		else
			self.nameTxt:setLocation(0, -52);
		end
		self.recordSp:setLocation(iconPosX, -68);
		self.scoreTxt:setLocation(-17, -68);
		self.avatarItem:setLocation(0, 108);
		self.noRankHeadImg:setLocation(0, 108);
		self.rankTxt:setLocation(0, 26);
		self.rankTxt:setLangValue(510016);
		self.nameTxt.fontSize = 30;
		self.nameTxt.effectColorStr = Lua_ColorDefine.transColorStr("BE9565")
	else
		self.avatarItem:setScale(0.8, 0.8);
		if data ~= nil then
			self.nameTxt:setLocation(0, -13);
		else
			self.nameTxt:setLocation(0, -40);
		end
		self.recordSp:setLocation(iconPosX, -51);
		self.scoreTxt:setLocation(-17, -51);
		self.avatarItem:setLocation(0, 96);
		self.noRankHeadImg:setLocation(0, 96);
		self.rankTxt:setLocation(0, 28);
		self.nameTxt.fontSize = 26;

		if rank == 2 then
			self.rankTxt:setLangValue(510017);
			self.nameTxt.effectColorStr = Lua_ColorDefine.transColorStr("767B85")
		else
			self.rankTxt:setLangValue(510018);
			self.nameTxt.effectColorStr = Lua_ColorDefine.transColorStr("A1827A")
		end
	end
	self.avatarItem:setEnable(data ~= nil);
end

function Lua_HeroTrialTopRankItem:onMaxFightInfoClick()
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end

function Lua_HeroTrialTopRankItem:dispose()
	self.data = nil;
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_HeroTrialRankItem = class("Lua_HeroTrialRankItem", Lua_ListCell);
function Lua_HeroTrialRankItem:ctor(p)
    self:superCall("ctor", p, "HeroTrialRankItem_skin");
end

function Lua_HeroTrialRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setLocation(-140, 0, 0)
	self.avatarItem:setScale(0.7, 0.7);

	self.recordSp:addClickFuntion(self, self.onMaxFightInfoClick);
end

function Lua_HeroTrialRankItem:setData(data)
	if data == nil then
		return;
	end
	self.data = data;

	self.numTxt.text = data.rank;
	self.nameTxt.text = data.player_show.name;
	self.valueTxt.text = LanUtil.formateStr(750010, data.value);

	self.avatarItem:setRoleDressUp(data.player_show.dress_info, true);
	self.avatarItem:setRoleLevel2(data.player_show.level);
end

function Lua_HeroTrialRankItem:onPressClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
	if self.avatarItem:checkInBound(winPos.x, winPos.y) then
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.data.player_show.id, self.data.player_show.server_flag);
	end
end

function Lua_HeroTrialRankItem:onMaxFightInfoClick()
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end

function Lua_HeroTrialRankItem:dispose()
	self.data = nil;
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end

	self:superCall("dispose");
end