-- 七天登录（新英雄后台活动）
Lua_SevenDaySignInPanel = class("Lua_SevenDaySignInPanel", Lua_DisplayObject);
function Lua_SevenDaySignInPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_SevenDaySignInPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.itemsTweenId = 2016;
	self.tipSp:addClickFuntion(self, self.onTipSpClick);
	self:addLuaEvent("DRAW_SEVENDAY_REWARD", self, self.drawSevenDayReward);
	self:addLuaEvent("UPDATE_SEVENDAY_LOGIN_INFO", self, self.updateSignInInfo);
end

function Lua_SevenDaySignInPanel:setData(data)
	self.data = data;
	self:startTimer();
	self:updateLeftTime();
end

function Lua_SevenDaySignInPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_SevenDaySignInPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_SevenDaySignInPanel:updateLeftTime()
	local time = self.data.residueTime;
	if time <= 0 then
		time = 0;
		self:endTimer();
	end
	self.leftTimeTxt.text = LanUtil.formateStr(740001, Lua_TimeTransform.transSeconds16(time, true, true, true));
end

function Lua_SevenDaySignInPanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.updateLeftTime);
	end
end

function Lua_SevenDaySignInPanel:onTipSpClick(go)
	local tipData = { des = self.data.help_des, posX = 185, posY = -226 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_SevenDaySignInPanel:drawSevenDayReward(day)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	if self.clickTime ~= nil and getTime() - self.clickTime <= 0.2 then
		OperateAlert.showLangValue(740007);
		return;
	end
	self.clickTime = getTime();
	Lua_ProxyManager.getProxy("Lua_NewHeroActivityProxy"):sDrawSevenDayLogin(self.data.actIdx, day);
end

function Lua_SevenDaySignInPanel:updateSignInInfo()
	if self.itemList == nil then
		self.itemList = {};
	end

	local sevenDayInfoDic = DataCenter.newHeroActData.sevenDayInfoDic;
	local count = #sevenDayInfoDic;
	local maxCount = 4;
	local distanceX, distanceY = 173, 279;
	local startPosX, startPosY = distanceX / 2, -651;
	local posX, posY;
	local row, col;
	local residueNum;
	local item;
	for i = 1, count do
		item = self.itemList[i];
		if item == nil then
			row = Mathf.Ceil(i / maxCount);
			col = i % maxCount;
			col = col == 0 and maxCount or col;
			residueNum = (count - (row - 1) * maxCount);
			residueNum = residueNum >= maxCount and maxCount or residueNum;
			posX = startPosX - residueNum * distanceX / 2 + (col - 1) * distanceX;
			posY = startPosY - (row - 1) * distanceY;

			item = Lua_SevenDaySignInItem.new(self.content);
			item:setRectAnchor(1);
			item:setLocation(posX, posY);
			self.itemList[i] = item;
		end
		item.content.name = "Lua_SevenDaySignInItem".. i;
		item:setData(sevenDayInfoDic[i]);
	end

	self:playItemsTween();
end

function Lua_SevenDaySignInPanel:dispose()
	self:stopItemsTween();
	if self.itemList ~= nil then
		for i = 1, #self.itemList do
			self.itemList[i]:dispose();
			self.itemList[i] = nil;
		end
	end
	self.data = nil;
	self:endTimer();
	self:superCall("dispose");
end


function Lua_SevenDaySignInPanel:playItemsTween()
	if self.itemList == nil or self.playedTween then
		return;
	end

 	local tweenData = Lua_UITweenConfigData.getConfigData(self.itemsTweenId);
    if tweenData == nil then
        return;
    end
    self.playedTween = true;

    local sevenDayInfoDic = DataCenter.newHeroActData.sevenDayInfoDic;
	local len = #sevenDayInfoDic;
    local item;
    local startPosX;
    local startPosY;
    local targetPosX, targetPosY;
    for i = 1, len do
        item = self.itemList[i];
        TweenUtil.getInstance():stop(item.content);

        if tweenData.startRot ~= nil then
            LuaUtil.setObjRot(item.content, tweenData.startRot.x, tweenData.startRot.y, tweenData.startRot.z);
        end

        startPosX = nil;
        startPosY = nil;
        if tweenData.startPos ~= nil then
            if tweenData.startPos.x ~= 0 then
                startPosX = tweenData.startPos.x * self.w;
                startPosY = item.y;
            elseif tweenData.startPos.y ~= 0 then
                startPosX = item.x;
                startPosY = tweenData.startPos.y * self.h;
            end
        end
        targetPosX = item.x;
        targetPosY = item.y;
        startPosX = startPosX == nil and item.x or startPosX;
        startPosY = startPosY == nil and item.y or startPosY;
        if tweenData.offsetPosTab ~= nil then
            startPosX = startPosX + tweenData.offsetPosTab[1];
            startPosY = startPosY + tweenData.offsetPosTab[2];
        end
        LuaUtil.setObjPos(item.content, startPosX, startPosY, 0);

        if tweenData.startScale ~= nil then
            LuaUtil.setObjScale(item.content, tweenData.startScale.x, tweenData.startScale.y, tweenData.startScale.z);
        end

        local delay = (i - 1) * tweenData.delayTime + tweenData.firstDelayTime;
        local offect = tweenData.offect;
        local targetRot = tweenData.targetRotTab;
        local targetScale = tweenData.targetScaleTab;
        item:setEnable(not tweenData.delayShow);

        if tweenData.bFade then
            TweenUtil.getInstance():addTweenTargetAlpha(item.content, tweenData.keepTime, delay, tweenData.fadeValue, tweenData.isFadeIn);
        end

        TweenUtil.getInstance():addTween(item.content, tweenData.keepTime, delay, 
            targetPosX, targetPosY, 0, 
            targetRot[1], targetRot[2], targetRot[3], 
            targetScale[1], targetScale[2], targetScale[3], 
            nil, nil, offect, tweenData.delayShow);
    end
 end

function Lua_SevenDaySignInPanel:stopItemsTween()
	if self.itemList == nil then
		return;
	end

	local item;
	local len = #self.itemList;
	for i = 1, len do
		item = self.itemList[i];
		TweenUtil.getInstance():stop(item.content);
	end
end

--------------------------------------------------





Lua_SevenDaySignInItem = class("Lua_SevenDaySignInItem", Lua_DisplayObject);
function Lua_SevenDaySignInItem:ctor(p)
	self:superCall("ctor", p, "SevenDaySignInItem_skin");
end

function Lua_SevenDaySignInItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardItem = Lua_ItemIcon.new(self.content);
	self.rewardItem:setScale(0.9, 0.9);
	self.rewardItem:setLocation(0, 35);
	self.rewardItem:setClick(self, self.onPressClick);
	self.rewardItem:setSiblingIndex(2);

	self.itemBg:addClickFuntion(self, self.onDrawRewardClick);

end

function Lua_SevenDaySignInItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local rewardState = data.state;
	self:showItemDisplay(rewardState);

	local tvo = Lua_ToolVo.createToolVo(data.itemId, data.itemCount);
	self.rewardItem:setData(tvo);
end

function Lua_SevenDaySignInItem:showItemDisplay(rewardState)
	if rewardState == 2 then
		self.itemBg:setAltas("new_hero_atlas_1", "xui_qtdl_widget_1");
		self.showTxt:setLangValue(740002);
		self:endTimer();
	elseif rewardState == 1 then
		self.itemBg:setAltas("new_hero_atlas_1", "xui_qtdl_widget_2");
		self.showTxt:setLangValue(740003);
		self:endTimer();
	else
		self.itemBg:setAltas("new_hero_atlas_1", "xui_qtdl_widget_1");
		local loginDay = DataCenter.newHeroActData.loginDay;
		if loginDay + 1 == self.data.day then
			self:startTimer();
			self:updateDrawTime();
		else
			self.showTxt.text = LanUtil.formateStr(740004, self.data.day);
		end
	end
	local colorStr = rewardState == 1 and "D48825" or "695E4A";
	self.showTxt.colorStr = Lua_ColorDefine.transColorStr(colorStr);

	self.drawedSp:setEnable(rewardState == 2);
	self.drawedItemBg:setEnable(rewardState == 2);
	self.itemBg.clickScale = rewardState ~= 2;
	self:showEffect(rewardState == 1);
end

function Lua_SevenDaySignInItem:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("Lua_SevenDaySignInItem", 1, self, self.updateDrawTime);
	end
end

function Lua_SevenDaySignInItem:updateDrawTime()
	local remainTime = DataCenter.newHeroActData.curdayEndTick - DataCenter.roleData.serverTime;
	if remainTime <= 0 then
		self.showTxt:setLangValue(740003);
		self:endTimer();
		return;
	end
	self.showTxt.text = Lua_TimeTransform.transSeconds6(remainTime, true, true, true);
end

function Lua_SevenDaySignInItem:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateDrawTime);
	end
end

function Lua_SevenDaySignInItem:onDrawRewardClick(go)
	if self.data.state == 1 then
		Lua_MsgUtil.callFunc("DRAW_SEVENDAY_REWARD", self.data.day);
	elseif self.data.state == 2 then
		OperateAlert.showLangValue(740005);
	elseif self.data.state == 0 then
		OperateAlert.showLangValue(740006);
	end
end

function Lua_SevenDaySignInItem:onPressClick()
	if self.data.state == 1 then
		Lua_MsgUtil.callFunc("DRAW_SEVENDAY_REWARD", self.data.day);
	else
		local tvo = Lua_ToolVo.createToolVo(self.data.itemId, self.data.itemCount);
		DataCenter.packUtil:showItemInfo(tvo);
	end
end

function Lua_SevenDaySignInItem:showEffect(bShow)
	if bShow then
		if self.uiEffect == nil then
	  		self.uiEffect = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_ty_zxjl_0101", "ui_ty_zxjl_0101", 0, 35);
	   	end
	   	self.uiEffect:setEnable(true);
	else
		if self.uiEffect ~= nil then
			self.uiEffect:setEnable(false);
		end
	end
end

function Lua_SevenDaySignInItem:dispose()
	if self.uiEffect ~= nil then
		self.uiEffect:dispose();
		self.uiEffect = nil;
	end
	if self.rewardItem ~= nil then
		self.rewardItem:dispose();
		self.rewardItem = nil;
	end
	self.data = nil;
	self:endTimer();
	self:superCall("dispose");
end