-- 商店热卖（新英雄后台活动）
Lua_ShopHotPanel = class("Lua_ShopHotPanel", Lua_DisplayObject);
function Lua_ShopHotPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_ShopHotPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.giftList = Lua_DragList.new(self.content, 687, 920 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.giftList.tweenId = 2002;
	self.giftList:setListCell(Lua_ShopHotItem, 687, 169, 1);
	self.giftList:setCellSpacing(0, 10);
	self.giftList:setRectAnchor(1);
	self.giftList:setLocation(-7.5, -835 - self.adaptHeight / 2, 0);

	self.ruleBtn:addClickFuntion(self, self.onRuleClick);

	self:addLuaEvent("UPDATE_SHOPHOT_INFO", self, self.updateShopHotInfo);
	self:addLuaEvent("BUY_SHOPHOT_RECHARGE_GIFT", self, self.buyShopHotRechargeGift);
	self:addLuaEvent("BUY_SHOPHOT_ITEM_GIFT", self, self.buyShopHotItemGift);
end

function Lua_ShopHotPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.giftList:setContentRect(687, 920 + adaptHeight);
	self.giftList:setLocation(-7.5, -835 - adaptHeight / 2, 0);
end

function Lua_ShopHotPanel:setData(data)
	self.data = data;
	self:startTimer();
	self:updateLeftTime();
end

function Lua_ShopHotPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_ShopHotPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_ShopHotPanel:updateLeftTime()
	local time = self.data.residueTime;
	if time <= 0 then
		time = 0;
		self:endTimer();
	end
	self.leftTimeTxt.text = LanUtil.formateStr(761200, Lua_TimeTransform.transSeconds16(time, true, true, true));
end

function Lua_ShopHotPanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.updateLeftTime);
	end
end

function Lua_ShopHotPanel:updateShopHotInfo()
	self.giftList:setArrayData(DataCenter.newHeroActData.shopHotArr);
end

function Lua_ShopHotPanel:buyShopHotRechargeGift(rechargeId)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(rechargeId);
	DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
		tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
end

function Lua_ShopHotPanel:buyShopHotItemGift(giftId)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_NewHeroActivityProxy"):sDrawShopHotReward(self.data.actIdx, giftId);
end

function Lua_ShopHotPanel:onRuleClick(go)
	local tipData = { des = self.data.help_des, posX = 185, posY = -240 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_ShopHotPanel:dispose()
	if self.giftList ~= nil then
		self.giftList:dispose();
		self.giftList = nil;
	end
	self.data = nil;
	self:endTimer();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_ShopHotItem = class("Lua_ShopHotItem", Lua_ListCell);
function Lua_ShopHotItem:ctor(p)
	self:superCall("ctor", p, "ShopHotItem_skin");
end

function Lua_ShopHotItem:buildShowItem()
	self:superCall("buildShowItem");

	self.tvoArr = Array();

	self.rewardList = Lua_DragList.new(self.content, 400, 87, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_ShopHotRewardItem, 87, 87, 1);
	self.rewardList:setCellSpacing(6, 0);
	self.rewardList:setRectPivot(3);
	self.rewardList:setLocation(-291, -13, 0);
	self:setSubList(self.rewardList);

	self.buyBtn:addClickFuntion(self, self.onBuyBtnClick);
end

function Lua_ShopHotItem:setData(data)
	self._data = DataCenter.newHeroActData:getTheShopHotVo(data);
	if data == nil then
		return;
	end

	self.titleTxt.text = self._data.title;
	self.limitTimesTxt.text = LanUtil.formateStr(761201, self._data.hasTimes, self._data.buyLimit);

	self.rewardList.canDrag = self._data.tvoArr:getSize() > 4;
	self.rewardList:setArrayData(self._data.tvoArr);

	if self._data.rechargeId ~= 0 then
		local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(self._data.rechargeId);
		self.buyBtn.label = LanUtil.formateStr(761202, tonumber(rechargeInfo.money));
	else
		if self._data.buyItem.value == 0 then
			self.buyBtn:setLangValue(761203);
		else
			self.buyBtn.label = spliceIconStrById(self._data.buyItem.key) .. self._data.buyItem.value;
		end
	end
	self.limitTimesTxt:setEnable(self._data.hasTimes > 0);
	self.buyBtn:setEnable(self._data.hasTimes > 0);
	self.sellOutIcon:setEnable(self._data.hasTimes <= 0);
	self:showRedDot(self._data.rechargeId == 0 and self._data.buyItem.value == 0 and self._data.hasTimes > 0);
end

function Lua_ShopHotItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(295, -9, 0);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_ShopHotItem:onBuyBtnClick()
	if self._data then
		if self._data.rechargeId ~= 0 then
			Lua_MsgUtil.callFunc("BUY_SHOPHOT_RECHARGE_GIFT", self._data.rechargeId);
		else
			if DataCenter.moneyData:isMoneyEnough(self._data.buyItem.key, self._data.buyItem.value, true, true) then
				Lua_MsgUtil.callFunc("BUY_SHOPHOT_ITEM_GIFT", self._data.giftId);
			end
		end
	end
end

function Lua_ShopHotItem:dispose()
	if self.tvoArr ~= nil then
		self.tvoArr:dispose();
		self.tvoArr:clear();
		self.tvoArr = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end










Lua_ShopHotRewardItem = class("Lua_ShopHotRewardItem", Lua_ItemIconCell);
function Lua_ShopHotRewardItem:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.7, 0.7);
end