-- 新英雄战令(后台活动)
Lua_WarCoinPanel = class("Lua_WarCoinPanel", Lua_DisplayObject)
function Lua_WarCoinPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_WarCoinPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.tipsTxt:setLangValue(761011);
	self.levelBar:setValue(0);

	local arr = Array();
	arr:add({str = LanUtil.getValue(761000), redPointId = Lua_RedPointList.NewHeroWarCoin_Level})
	arr:add({str = LanUtil.getValue(761001), redPointId = Lua_RedPointList.NewHeroWarCoin_Task})
	self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.btnList:setButtonCell(Lua_WarCoinBtnItem);
	self.btnList:setButtonItem(150, 52);
	self.btnList:setClickCallBack(self, self.onBtnClick);
	self.btnList:setRedPoint(60, 17);
	self.btnList:setRectAnchor(1);
	self.btnList:setLocation(-183, -371);
	self.btnList:setData(arr);
	self.btnList:setSelected(1);

	self.ruleBtn:addClickFuntion(self, self.onRuleClick);
	self.upLevelBtn:addClickFuntion(self, self.onUpLevelClick);
	self.buyBtn:addClickFuntion(self, self.onBuyBtnClick);

	self:addLuaEvent("UPDATE_WARCOIN_INFO", self, self.updatePanel);
	self:addLuaEvent("DRAW_WARCOIN_LV_REWARD", self, self.onDrawLvReward);
	self:addLuaEvent("DRAW_WARCOIN_TASK_REWARD", self, self.onDrawTaskReward)
end

function Lua_WarCoinPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	if self.levelList then
		self.levelList:setContentRect(678, 750 + adaptHeight);
	end
	if self.dailyTaskList then
		self.dailyTaskList:setContentRect(688, 315 + adaptHeight / 2);
		self.periodTaskList:setContentRect(688, 420 + adaptHeight / 2);
	end
end

function Lua_WarCoinPanel:setData(actVo)
	self.actVo = actVo;
	if actVo == nil then
		return;
	end
	self:startActTimer();
end

function Lua_WarCoinPanel:startActTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:updateActTimer();
		self:addTimer("OnWarCoinTimer_Act", 1, self, self.updateActTimer);
	end
end

function Lua_WarCoinPanel:updateActTimer()
	local time = self.actVo.residueTime;
	self.timeTxt.text = LanUtil.formateStr(761003, Lua_TimeTransform.transSeconds16(time, true, true, true));
	self.periodTaskTimeTxt.text = LanUtil.formateStr(761014, Lua_TimeTransform.transSeconds20(time, true, true));
	if time <= 0 then
		self.timeTxt:setLangValue(761002);
		self.periodTaskTimeTxt.text:setLangValue(761012);
		self:endActTimer();
	end
end

function Lua_WarCoinPanel:endActTimer()
	if self.bTimer == true then
		self.bTimer = false;
		Lua_CommonUtil.removeTimer(self, self.updateActTimer);
	end
end

function Lua_WarCoinPanel:onBtnClick(val)
	if self.levelList then
		self.levelList.showTween = val == 1;
		self.levelList:setEnable(val == 1);
	end
	if self.dailyTaskList then
		self.dailyTaskList:setEnable(val == 2);
		self.periodTaskList:setEnable(val == 2);
	end
	self.desTxt_1:setEnable(val == 1);
	self.desTxt_2:setEnable(val == 1);
	self.desTxt_3:setEnable(val == 1);
	self.lockIcon:setEnable(val == 1);
	self.buyBtn:setEnable(val == 1);
	self.lineIcon:setEnable(val == 2);
	self.taskTimeBg:setEnable(val == 2);
	self.dailyTaskTimeTxt:setEnable(val == 2);
	self.periodTaskTimeTxt:setEnable(val == 2);

	local isEnter = true;
	if self.selectType == nil then
		isEnter = false;
	end
	self.selectType = val;

	-- 用于列表播放动画
	if isEnter then
		self:updatePanel();
	end
end

function Lua_WarCoinPanel:updatePanel()
	local state = DataCenter.newHeroActData.rechargeState;
	self.levelTxt.text = DataCenter.newHeroActData.level;
	self.lockIcon:setEnable(state == 0 and self.selectType == 1);

	local curExe = DataCenter.newHeroActData.curExe;
	local totalExe = DataCenter.newHeroActData.totalExe;
	self.levelBar:setMaxValue(totalExe);
	self.levelBar:setValue(curExe);
	self.levelBar:setText(LanUtil.formateStr(761004, curExe, totalExe));

	if state == 0 then
		local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(DataCenter.newHeroActData.warCoinRechargeId);
		if rechargeInfo ~= nil then
			self.buyBtn.label = LanUtil.formateStr(761005, tonumber(rechargeInfo.money));
		end
	else
		self.buyBtn:setLangValue(761006);
		self.buyBtn:setBtnEnable(false);
	end

	if self.selectType == 1 then
		self:updateLevelInfo();
	else
		self:updateTaskInfo();
	end
end

function Lua_WarCoinPanel:updateLevelInfo()
	if self.levelList == nil then
		self.levelList = Lua_DragList.new(self.content, 678, 750 + self.adaptHeight, Lua_AxisDefine.Vertical);
		self.levelList.tweenId = 2025;
		self.levelList.delayTween = true;
		self.levelList:setListCell(Lua_WarCoinLevelItem, 678, 118, 1);
		self.levelList:setCellSpacing(0, 10);
		self.levelList:setLocation(0, -110);
	end
	self.levelList:setArrayData(DataCenter.newHeroActData.warCoinRewardList);
	self.levelList:moveToIndex(DataCenter.newHeroActData.showLvIdx, true, false);
end

function Lua_WarCoinPanel:updateTaskInfo()
	if self.dailyTaskList == nil then
		self.dailyTaskList = Lua_DragList.new(self.content, 688, 315 + self.adaptHeight / 2, Lua_AxisDefine.Vertical);
		self.dailyTaskList:setListCell(Lua_WarCoinTaskItem, 344, 154, 2);
		self.dailyTaskList:setCellSpacing(0, 6);
		self.dailyTaskList:setRectPivot(1);
		self.dailyTaskList:setRectAnchor(1);
		self.dailyTaskList:setLocation(0, -449);

		self.periodTaskList = Lua_DragList.new(self.content, 688, 420 + self.adaptHeight / 2, Lua_AxisDefine.Vertical);
		self.periodTaskList:setListCell(Lua_WarCoinTaskItem, 344, 154, 2);
		self.periodTaskList:setCellSpacing(0, 6);
		self.periodTaskList:setRectPivot(1);
		self.periodTaskList:setLocation(0, -98);
	end
	self.dailyTaskList:setArrayData(DataCenter.newHeroActData.dailyTaskArr);
	self.periodTaskList:setArrayData(DataCenter.newHeroActData.periodTaskArr);

	self:startTaskTimer();
end

function Lua_WarCoinPanel:startTaskTimer()
	if self.bTaskTimer ~= true then
		self.bTaskTimer = true;
		self:updateTaskTimer();
		self:addTimer("OnWarCoinTimer_Task", 1, self, self.updateTaskTimer);
	end
end

function Lua_WarCoinPanel:updateTaskTimer()
	local time = DataCenter.newHeroActData.dailyTaskTime - DataCenter.roleData.serverTime;
	self.dailyTaskTimeTxt.text = LanUtil.formateStr(761013, Lua_TimeTransform.transSeconds20(time, true, true, true));
	if time <= 0 then
		self.dailyTaskTimeTxt:setLangValue(761012);
		self:endTaskTimer();
	end
end

function Lua_WarCoinPanel:endTaskTimer()
	if self.bTaskTimer == true then
		self.bTaskTimer = false;
		Lua_CommonUtil.removeTimer(self, self.updateTaskTimer);
	end
end

function Lua_WarCoinPanel:onUpLevelClick()
	local curExe = DataCenter.newHeroActData.curExe;
	local totalExe = DataCenter.newHeroActData.totalExe;
	if curExe >= totalExe then
		OperateAlert.showLangValue(761018);
	else
		self:onWarCoinOperate(1);
	end
end

function Lua_WarCoinPanel:onBuyBtnClick()
	self:onWarCoinOperate(2);
end

function Lua_WarCoinPanel:onDrawLvReward()
	self:onWarCoinOperate(3);
end

function Lua_WarCoinPanel:onDrawTaskReward(id)
	self:onWarCoinOperate(4, id);
end

function Lua_WarCoinPanel:onWarCoinOperate(operateType, param)
	if DataCenter.backstageActData:checkActIsEnd(self.actVo) then
		return;
	end

	if operateType == 1 then
		Lua_WindowUtil.openWin("Lua_NewHeroWarCoinBuyLvWindow", Lua_WinParam.ACTION_OPEN, self.actVo.actIdx);
	elseif operateType == 2 then
		Lua_WindowUtil.openWin("Lua_WarCoinRewardWindow", Lua_WinParam.ACTION_OPEN, self.actVo);
	elseif operateType == 3 then
		Lua_ProxyManager.getProxy("Lua_NewHeroActivityProxy"):sDrawWarCoinReward(self.actVo.actIdx);
	elseif operateType == 4 then
		Lua_ProxyManager.getProxy("Lua_NewHeroActivityProxy"):sDrawWarCoinExp(self.actVo.actIdx, param);
	end
end

function Lua_WarCoinPanel:onRuleClick()
	local tipData = { des = self.actVo.help_des, posX = 206, posY = -230 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_WarCoinPanel:dispose()
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.levelList ~= nil then
		self.levelList:dispose();
		self.levelList = nil;
	end
	if self.dailyTaskList ~= nil then
		self.dailyTaskList:dispose();
		self.dailyTaskList = nil;
	end
	if self.periodTaskList ~= nil then
		self.periodTaskList:dispose();
		self.periodTaskList = nil;
	end
	self.actVo = nil;
	self:endActTimer();
	self:endTaskTimer();

	self:superCall("dispose");
end










Lua_WarCoinBtnItem = class("Lua_WarCoinBtnItem", Lua_ButtonCell)
function Lua_WarCoinBtnItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_WarCoinBtnItem:buildShowItem()
	self:superCall("buildShowItem");

	self.bg = UICreate.createUIAtlasImage(self.content, "", "", 0, 0, 140, 52);
	self.titleTxt = UICreate.createLabel(self.content, "", 0, 0, 100, 40, 28);
	self.titleTxt.fontName = Lua_MyUISettings.huakangFontName;
	self.titleTxt.alignmentValue = 4;
	self.titleTxt.horizontalOverflowValue = 1;

	self.bg:addClickFuntion(self, self.onPressClick);
end

function Lua_WarCoinBtnItem:setData(data)
	self:superCall("setData", data);
	if data == nil then
		return;
	end
	self.titleTxt.text = data.str;
end

function Lua_WarCoinBtnItem:setSelected(val)
	if val == self.index then
		self.bg:setAltas("war_order_atlas", "xui_zl_toggle_01_f");
		self.titleTxt.colorStr = Lua_ColorDefine.transColorStr("8F5123");
	else
		self.bg:setAltas("war_order_atlas", "xui_zl_toggle_01_b");
		self.titleTxt.colorStr = Lua_ColorDefine.transColorStr("F5DBB1");
	end
end










Lua_WarCoinLevelItem = class("Lua_WarCoinLevelItem", Lua_ListCell)
function Lua_WarCoinLevelItem:ctor(p)
	self:superCall("ctor", p, "WarCoinLvItem_skin");
end

function Lua_WarCoinLevelItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemArr = Array();

	self.dragList = Lua_DragList.new(self.content, 248, 93, Lua_AxisDefine.Horizontal);
	self.dragList:setListCell(Lua_WarCoinItemIconCell, 93, 93, 1);
	self.dragList:setCellSpacing(10, 10);
	self.dragList:setLocation(142, 0);
	self:setSubList(self.dragList);
end

function Lua_WarCoinLevelItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.levelTxt.text = data.level;
	local level = DataCenter.newHeroActData.level or 1;
	local spriteName = level >= data.level and "xui_zl_widget_5" or "xui_zl_widget_4";
	self.levelBg:setAltas("war_order_atlas", spriteName);
	self.lockIcon:setEnable(DataCenter.newHeroActData.rechargeState == 0);

	local rewardInfo = data.reward_item;
	local arrLen = self.itemArr:getSize();
	local maxLen = arrLen > #rewardInfo and arrLen or #rewardInfo;
	local startPosX = -140 - (maxLen - 1) * 103 / 2;
	local item;
	for i = 1, maxLen do
		item = self.itemArr[i];
		if i > #rewardInfo then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_WarCoinItemIconCell.new(self.content);
				self.itemArr:add(item);
			end
			item.itemIcon:showRedPoint(data.reward_state == 1);
			item.itemIcon:setDrawMask(data.reward_state == 2);
			item:setData(rewardInfo[i]);
			item:setLocation(startPosX + (i - 1) * 103, 0);
		end
	end

	rewardInfo = data.stage_reward_item;
	self.dragList.canDrag = #rewardInfo >= 3;
	self.dragList:setArrayData(rewardInfo);
	local arr = self.dragList.showList;
	for i = 1, arr:getSize() do
		arr[i].itemIcon:showRedPoint(data.stage_reward_state == 1);
		arr[i].itemIcon:setDrawMask(data.stage_reward_state == 2);
	end
end

function Lua_WarCoinLevelItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		if self.pressType == 1 then
			self.pressItem:onMouseDownHandle();
		elseif self.pressType == 2 then
			if #self.data.stage_reward_item < 3 then
				self.pressItem:onMouseDownHandle();
			end
		end
	end
end

function Lua_WarCoinLevelItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		if self.pressType == 1 then
			self.pressItem:onMouseUpHandle();
		elseif self.pressType == 2 then
			if #self.data.stage_reward_item < 3 then
				self.pressItem:onMouseUpHandle();
			end
		end
	end
end

function Lua_WarCoinLevelItem:checkClick()
	local winPos;
	local item;
	for i = 1, self.itemArr:getSize() do
		item = self.itemArr[i];
		winPos = LuaUtil.getTouchPosInverseObj(item.content)
		if item.itemIcon:checkInBound(winPos.x, winPos.y) then
			self.pressType = 1;
			return item;
		end
	end

	winPos = LuaUtil.getTouchPosInverseObj(self.dragList.sub);
	for i = 1, self.dragList.showList:getSize() do
		item = self.dragList.showList[i];
		if item:checkInBound(winPos.x, winPos.y) then
			self.pressType = 2;
			return item;
		end
	end
	return nil;
end

function Lua_WarCoinLevelItem:onPressClick()
	if self.pressItem == nil then
		return;
	end
	if self.pressType == 1 then
		if self.data.reward_state == 1 then
			Lua_MsgUtil.callFunc("DRAW_WARCOIN_LV_REWARD");
		else
			self.pressItem.itemIcon:onItemClick();
		end
	elseif self.pressType == 2 then
		if self.data.stage_reward_state == 1 then
			Lua_MsgUtil.callFunc("DRAW_WARCOIN_LV_REWARD");
		else
			self.pressItem.itemIcon:onItemClick();
		end
	end
end

function Lua_WarCoinLevelItem:dispose()
	if self.itemArr ~= nil then
		self.itemArr:dispose();
		self.itemArr:clear();
		self.itemArr = nil;
	end
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	self.data = nil;
	self.pressItem = nil;
	self:superCall("dispose");
end










Lua_WarCoinItemIconCell = class("Lua_WarCoinItemIconCell", Lua_ItemIconCell)
function Lua_WarCoinItemIconCell:ctor(p)
	self:superCall("ctor", p);
end

function Lua_WarCoinItemIconCell:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.75, 0.75);
end

function Lua_WarCoinItemIconCell:setData(data)
	if data == nil then
		return;
	end

	if self.tvo == nil then
		self.tvo = Lua_ToolVo.createToolVo(data.key, data.value);
	else
		self.tvo:setData(data.key, data.value);
	end
	self.itemIcon:setData(self.tvo);
end

function Lua_WarCoinItemIconCell:onMouseDownHandle()
	self.itemIcon:setScale(0.71, 0.71);
end

function Lua_WarCoinItemIconCell:onMouseUpHandle()
	self.itemIcon:setScale(0.75, 0.75);
end

function Lua_WarCoinItemIconCell:dispose()
	self.tvo = nil;
	self:superCall("dispose");
end










Lua_WarCoinTaskItem = class("Lua_WarCoinTaskItem", Lua_ListCell)
function Lua_WarCoinTaskItem:ctor(p)
	self:superCall("ctor", p, "WarCoinTaskItem_skin");
end

function Lua_WarCoinTaskItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(-103, 0);
	self.itemIcon:setScale(0.82, 0.82);
end

function Lua_WarCoinTaskItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.goTaskTxt.text = nil; -- 对下滑线处理
	self.goTaskTxt:setLangValue(761019);

	local showNum = data.task_type == 1 and data.exe.value or 0;
	if self.tvo == nil then
		self.tvo = Lua_ToolVo.createToolVo(data.exe.key, showNum);
	else
		self.tvo:setData(data.exe.key, showNum);
	end
	self.itemIcon:setData(self.tvo);
	self.itemIcon:setDrawMask(data.reward_state == 2);

	self.countTxt.text = LanUtil.formateStr(761008, data.limit_times - data.finish_times);
	local desStr;
	if data.task_type == 1 then
		if data.limit_times - data.finish_times <= 0 then
			desStr = LanUtil.formateStr(761009, data.dec, data.process, data.process);
		else
			desStr = LanUtil.formateStr(761009, data.dec, data.cur_process, data.process);
		end
	else
		desStr = LanUtil.formateStr("{1}", data.dec);
	end
	self.desTxt.text = desStr;
	self.desTxt:resetSize();

	local spriteName = data.reward_state == 1 and "xui_xyx_zl_widget_4" or "xui_xyx_zl_widget_3";
	self.itemBg:setAltas("war_order_atlas", spriteName);

	self.countTxt:setEnable(data.task_type == 1);
	self.goTaskTxt:setEnable(data.task_type == 2);
	self.maskBg:setEnable(data.reward_state == 2);
	self.drawIcon:setEnable(data.reward_state == 2);
	self.drawBg:setEnable(data.reward_state == 1);
	self:setRedDot(data.reward_state == 1 and DataCenter.newHeroActData.curExe < DataCenter.newHeroActData.totalExe);
end

function Lua_WarCoinTaskItem:setRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(153, 60, 0);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_WarCoinTaskItem:onMouseDownHandle()
	local winPos = LuaUtil.getTouchPosInverseObj(self.content);
	if self.itemIcon:checkInBound(winPos.x, winPos.y) then
		self.itemIcon:setScale(0.78, 0.78);
	else
	end
end

function Lua_WarCoinTaskItem:onMouseUpHandle()
	self.itemIcon:setScale(0.82, 0.82);
end

function Lua_WarCoinTaskItem:onPressClick()
	if self.data.reward_state == 1 then
		Lua_MsgUtil.callFunc("DRAW_WARCOIN_TASK_REWARD", self.data.task_id);
	else
		local winPos = LuaUtil.getTouchPosInverseObj(self.content);
		if self.itemIcon:checkInBound(winPos.x, winPos.y) then
			self.itemIcon:onItemClick();
		else
			if not (self.data.task_type == 1 and self.data.limit_times - self.data.finish_times <= 0) then
				-- print("Lua_WarCoinPanel", self.data.fun_id);
				if self.data.fun_id then
					DataCenter.funcPathUtil:gotoFunction(self.data.fun_id, true);
				end
			end
		end
	end
end

function Lua_WarCoinTaskItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.tvo = nil;
	self.data = nil;
	self:superCall("dispose");
end