-- 超值周卡
Lua_SuperWeekCardPanel = class("Lua_SuperWeekCardPanel", Lua_DisplayObject)
function Lua_SuperWeekCardPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_SuperWeekCardPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.topDragList = Lua_DragList.new(self.rewardObj_1, 630, 124, Lua_AxisDefine.Horizontal);
	self.topDragList:setListCell(Lua_SuperWeekCardIconCell, 124, 124, 1);
	self.topDragList:setCellSpacing(20, 0);
	self.topDragList:setLocation(0, -30);

	self.downDragList = Lua_DragList.new(self.rewardObj_2, 630, 124, Lua_AxisDefine.Horizontal);
	self.downDragList:setListCell(Lua_SuperWeekCardIconCell, 124, 124, 1);
	self.downDragList:setCellSpacing(20, 0);
	self.downDragList:setLocation(0, -30);

	self.buyBtn:addClickFuntion(self, self.onBuyBtnClick);
	self:addLuaEvent("SHOW_WEEKCARD_PANEL", self, self.updateSuperWeekCardInfo);
end

function Lua_SuperWeekCardPanel:setData(actVo)
	if actVo == nil then
		return;
	end
	self.actVo = actVo;
	self:starTimer();
	self:updateLeftTime();
end

function Lua_SuperWeekCardPanel:starTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_SuperWeekCardPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_SuperWeekCardPanel:updateLeftTime()
	local time = Lua_TimeTransform.transSeconds16(self.actVo.residueTime, true, true, true, true);
	self.timeTxt.text = LanUtil.formateStr(700000, time);
	if self.actVo.residueTime <= 0 then
		self.timeTxt:setLangValue(700003);
		self:stopTimer();
	end
end

function Lua_SuperWeekCardPanel:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

function Lua_SuperWeekCardPanel:updateSuperWeekCardInfo(msg)
	if msg == nil then
		return;
	end
	self.rechargeId = msg.recharge_id;

	local reward = msg.draw_reward;
	local posX = #reward > 4 and 0 or (630 - #reward * 144 + 20) / 2;
	self.topDragList.canDrag = #reward > 4;
	self.topDragList:setArrayData(reward);
	self.topDragList:setLocation(posX, -30, 0);

	local dayReward = msg.daily_reward;
	local posX = #dayReward > 4 and 0 or (630 - #dayReward * 144 + 20) / 2;
	self.downDragList.canDrag = #dayReward > 4;
	self.downDragList:setArrayData(dayReward);
	self.downDragList:setLocation(posX, -30, 0);

	local state = msg.unlock_state;
	if state == 1 then
		self.btnText:setLangValue(700002);
	else
		local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(msg.recharge_id);
		if rechargeInfo ~= nil then
			self.btnText.text = LanUtil.formateStr(700001, rechargeInfo.money);
		end
	end
	self.buyBtn.mouseEnable = state == 0;
	self.buyBtn:setGray(state == 1);
	self.btnText:setGray(state == 1);
end

function Lua_SuperWeekCardPanel:onBuyBtnClick()
	local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(self.rechargeId);
	if DataCenter.backstageActData:checkActIsEnd(self.actVo) or rechargeInfo == nil then
		return;
	end
	DataCenter.sdkInterface:PointOut(tonumber(rechargeInfo.gold), tonumber(rechargeInfo.money),
		tonumber(rechargeInfo.money_type), tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
end

function Lua_SuperWeekCardPanel:dispose()
	if self.topDragList ~= nil then
		self.topDragList:dispose();
		self.topDragList = nil;
	end
	if self.downDragList ~= nil then
		self.downDragList:dispose();
		self.downDragList = nil;
	end
	self.actVo = nil;
	self:stopTimer();
	self:superCall("dispose");
end










Lua_SuperWeekCardIconCell = class("Lua_SuperWeekCardIconCell", Lua_ItemIconCell);
function Lua_SuperWeekCardIconCell:onMouseDownHandle()
	self.itemIcon:setScale(0.95, 0.95, 1);
end

function Lua_SuperWeekCardIconCell:onMouseUpHandle()
	self.itemIcon:setScale(1, 1, 1);
end