-- 百发百中游玩挑战界面
Lua_CrackShotChallengeWindow = class("Lua_CrackShotChallengeWindow", Lua_Window);
function Lua_CrackShotChallengeWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_CrackShotChallengeWindow";
	self.skinName = "CrackShotChallengeWindow_skin";
	self.isFullSizeWin = true;
	self.showWinBg = true;
	self.showBackBtn = true;
	self.winBgPath = "/images/activities/xui_bfbz_bg_3.jpg";
end

function Lua_CrackShotChallengeWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.winBg.anchorValue = 4;
	self.winBg.pivotValue = 4;
	self.balloonArr = Array();

	self.countdownNum = Lua_NumberImage.new(self.content);
	self.countdownNum.pivot = 0;
	self.countdownNum.numAtlas = "number";
	self.countdownNum.preStr = "xui_bfbz_number2_";
	self.countdownNum:setLocation(0, 0, 0);

	self.backBtn.siblingIndex = 10;
	self.openMask:addClickFuntion(self, self.onMaskClick);
	-- self.shotBtn:addClickFuntion(self, self.onShotClick);
	self.shotBtn:addMousDownFuntion(self, self.onShotClick);

	self:showShotEff(false);

	self:addLuaEvent("UPDATE_CRACKSHOT_INFO", self, self.showMaxCrackShotInfo);
	self:addLuaEvent("UPDATE_CRACKSHOT_ROUNDINFO", self, self.updateCrackShotRoundInfo);
	self:addLuaEvent("UPDATE_CRACKSHOT_CHALLENGE", self, self.updateShotInfo);
end

function Lua_CrackShotChallengeWindow:showWin(param)
	self:superCall("showWin", param);
	self:showMaxCrackShotInfo();
	self:init();
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sCrackShotLevelInfo(param.actVo.actIdx,
		param.levelInfo.diffType, param.levelInfo.selectLevelGrade);
end

function Lua_CrackShotChallengeWindow:showMaxCrackShotInfo()
	local topPlayerInfo = self.showData.levelInfo.top_player;
	local name = topPlayerInfo.player_show.name;
	if strIsNullOrEmpty(name) then
		name = LanUtil.getValue(768022);
	end
	self.nameTxt.text = LanUtil.formateStr(768015, name);
	self.maxScoreTxt.text = LanUtil.formateStr(768016, topPlayerInfo.value);
end

function Lua_CrackShotChallengeWindow:init()
	self.shotRangeState = 1; -- 1未进范围，2范围内，3超出范围
	self.shotTimes = 0; -- 射击气球次数
	self.recordPreScore = 0; -- 比对显示评价特效
	self.showSmallRound = 1; -- 小轮
	self.showBigRound = 1; -- 多个小轮为一个大轮
	self.hasPlayRound = 1; -- 已经游玩的总轮次（小轮）
	self.isClick = true;

	self.direction = 1; -- 顺时针，逆时针
	self.speed = 1;
	self.radius = 190;
	self.infoPosX = 0;
	self.infoPosY = -140;
	self._angle = 90; -- 默认位置固定
	self.shotIcon:setLocation(0, self.infoPosY + self.radius, 0);

	self.shotTxt:setLangValue(768017);
	self.isOpen = false;
	self.backBtn.mouseEnable = true;
	self:setOpenState(false);
end

function Lua_CrackShotChallengeWindow:setOpenState(isShow)
	self.openMask:setEnable(isShow);
	self.tipsTxt:setEnable(isShow);
	self.countdownNum:setEnable(isShow);
	if isShow then
		self:startPlayTimer();
		self:updateShowTimer();
	end
end

function Lua_CrackShotChallengeWindow:startPlayTimer()
	if self.countDown ~= true then
		self.countDown = true;
		self.remainTime = 3;
		self.rotateTime = getTime();
		Lua_CommonUtil.addTimer("Lua_CrackShotGetPosWindow", 0.01, self, self.updateShowTimer, nil, -1, true);
	end
end

function Lua_CrackShotChallengeWindow:updateShowTimer()
	local newTime = getTime();
	local dt = newTime - self.rotateTime;
	self.remainTime = self.remainTime - dt;
	self.rotateTime = newTime;
	if self.remainTime > 0 then
		self.countdownNum.num = Mathf.Ceil(self.remainTime);
	else
		if not self.isFirstIn then
			self.shotTxt:setLangValue(768018);
			self.backBtn.mouseEnable = false;
			self:setOpenState(false);
			self:setCurMinRoundInfo();
			self.frontMinAngleMinusIdx = self:getFrontMinAngleMinusIdx();
			self.isFirstIn = true;
		end
		self:onRotateFun(dt);
	end
end

function Lua_CrackShotChallengeWindow:endPlayTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateShowTimer, true);
	end
end

function Lua_CrackShotChallengeWindow:onRotateFun(dt)
	if dt > 1 / 24 then
		dt = 1 / 24;
	end

	local changeAngle = dt * self.speed;
	self.angle = self.angle + self.direction * changeAngle;
	-- print("onRotateFun ", dt, changeAngle);
	if self.distanceMin and self.distanceMax then
		local state = 1; -- 1未进范围，2范围内，3超出范围
		self.distanceMin = self.distanceMin - changeAngle;
		self.distanceMax = self.distanceMax - changeAngle;
		if self.distanceMin > 0 then
			state = 1;
		else
			if self.distanceMax >= 0 then
				state = 2;
			else
				state = 3;
			end
		end

		self.shotRangeState = state;
		if state == 3 then -- 超出判断错误
			self.isClick = false;
			self:shotFun(self.angle, 0);
			self:endPlayTimer();
		end
		self.shotIcon:setAltas("crack_shot_atlas", state == 2 and "xui_bfbz_widget_17" or "xui_bfbz_widget_16");
	end
end

function Lua_CrackShotChallengeWindow.Get:angle()
	return self._angle;
end

function Lua_CrackShotChallengeWindow.Set:angle(val)
	if val and self._angle ~= val then
		self._angle = val % 360; -- 0 ~ 2 * Mathf.PI

		self.shotIcon:setRot(0, 0, self._angle);
		local imgPosX = self.radius * Mathf.Cos(Mathf.Rad(self._angle)) + self.infoPosX;
		local imgPosY = self.radius * Mathf.Sin(Mathf.Rad(self._angle)) + self.infoPosY;
		self.shotIcon:setLocation(imgPosX, imgPosY, 0);
	end
end

-- 更新大轮信息
function Lua_CrackShotChallengeWindow:updateCrackShotRoundInfo(msg)
	if msg == nil then
		return;
	end
	if self.bigRoundDic == nil then
		self.bigRoundDic = {};
	end
	self.bigRoundDic[#self.bigRoundDic + 1] = msg;
end

-- 更新处理界面得分
function Lua_CrackShotChallengeWindow:updateShotInfo(msg)
	if msg == nil then
		return;
	end

	if msg.state == 1 then -- 射击判定 0失败 1成功
		self.myScoreTxt.text = msg.latest_score;
		local changeScore = msg.latest_score - self.recordPreScore;
		local showResult = self.showData.levelInfo:getShowGrade(changeScore);
		self.recordPreScore = msg.latest_score;
		self:showResultEff(showResult);
	else
		self:endPlayTimer();
		Lua_WindowUtil.openWin("Lua_CrackShotResultWindow", Lua_WinParam.ACTION_OPEN, {levelInfo = self.showData.levelInfo, result = msg.latest_score});
	end
end

-- 设置小轮信息
function Lua_CrackShotChallengeWindow:setCurMinRoundInfo()
	if self.balloonAngleInfoArr == nil then
		self.balloonAngleInfoArr = Array();
	else
		self.balloonAngleInfoArr:clear();
	end

	local info = self.bigRoundDic[self.showBigRound];
	if info == nil then
		return;
	end
	self.direction = info[self.showSmallRound].direction == 1 and -1 or 1; -- 1顺时针，2逆时针
	self.speed = self.showData.levelInfo:getCurSpeed(self.hasPlayRound);
	-- print(self.showBigRound, self.showSmallRound, self.hasPlayRound, self.direction, self.speed, #position);

	local arrLen = self.balloonArr:getSize();
	local position = info[self.showSmallRound].position;
	local maxLen = #position >= arrLen and #position or arrLen;
	local icon, iconAngle;
	for i = 1, maxLen do
		icon = self.balloonArr[i];
		if i > #position then
			icon:setEnable(false);
		else
			-- Mathf.Atan2 -> -Mathf.PI ~ Mathf.PI
			local posX = position[i].key - self.infoPosX;
			local posY = position[i].value - self.infoPosY;
			iconAngle = Mathf.Atan2(posY, posX) * 180 / Mathf.PI;
			iconAngle = (iconAngle < 0 and iconAngle + 360 or iconAngle) % 360;
			self.balloonAngleInfoArr:add(iconAngle);

			if icon == nil then
				icon = UICreate.createUIAtlasImage(self.content, "crack_shot_atlas", "xui_bfbz_widget_15", 0, 0, 0, 0);
				self.balloonArr:add(icon);
			end
			icon.siblingIndex = 7;
			icon:setEnable(true);
			icon:setLocation(position[i].key, position[i].value, 0);
			icon:setRot(0, 0, -90 + iconAngle);
		end
	end
end

-- 显示评价
function Lua_CrackShotChallengeWindow:showResultEff(showResult)
	local effectName = DataCenter.crackShotData:getEffectName(showResult);
	if effectName ~= nil then
		local url = "/effects/uiEffects/"..effectName;
		if self.uiEffect == nil then
			self.uiEffect = UICreate.createUIEffect(self.content, url, effectName, 0, -77);
		else
			self.uiEffect:setUrl(url, effectName);
		end
		self.uiEffect:setEnable(false);
		self.uiEffect:setEnable(true);
	end
end

function Lua_CrackShotChallengeWindow:onMaskClick(go)
end

function Lua_CrackShotChallengeWindow:onShotClick(go)
	if DataCenter.backstageActData:checkActIsEnd(self.showData.actVo) then
		local score = self.myScoreTxt.text;
		score = strIsNullOrEmpty(score) and 0 or tonumber(score);
		Lua_WindowUtil.openWin("Lua_CrackShotResultWindow", Lua_WinParam.ACTION_OPEN, {levelInfo = self.showData.levelInfo, result = score});
		return;
	end

	-- 未开始
	if not self.isOpen then
		DataCenter.crackShotData.isCrackShotTween = true;
		self.isOpen = true;
		self:shotFun(0, 1);
		self:setOpenState(true);
		DataCenter.connectionManager:setCollectInfo(300);
		return;
	end

	-- 开始射击气球
	if not self.isClick or not self.isFirstIn then
		return;
	end

	self:shotFun(self.angle, 0);
	self:showShotEff(true);
	if self.shotRangeState == 2 then
		self.balloonArr[self.frontMinAngleMinusIdx]:setEnable(false);
		self.distanceMin = nil;
		self.distanceMax = nil;

		-- 设置小轮气球
		local isRefresh = false;
		self.shotTimes = self.shotTimes + 1;
		if self.shotTimes >= self.balloonAngleInfoArr:getSize() then
			isRefresh = true;
			self.shotTimes = 0;
			self.hasPlayRound = self.hasPlayRound + 1;
			self.showSmallRound = self.showSmallRound + 1;
		end

		local info = self.bigRoundDic[self.showBigRound];
		if info then
			if self.showSmallRound == #info then -- 提前获取下一个大轮的信息
				Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sCrackShotLevelInfo(self.showData.actVo.actIdx,
					self.showData.levelInfo.diffType, self.showData.levelInfo.selectLevelGrade);
			elseif self.showSmallRound > #info then
				self.showSmallRound = 1;
				self.showBigRound = self.showBigRound + 1;
			end
		end
		if isRefresh then
			self:setCurMinRoundInfo();
		end
		self.frontMinAngleMinusIdx = self:getFrontMinAngleMinusIdx();
	else
		self:endPlayTimer();
	end
end

function Lua_CrackShotChallengeWindow:shotFun(angle, isFirst)
	local targetAngle;
	if self.balloonAngleInfoArr == nil then
		targetAngle = 0;
	else
		targetAngle = self.balloonAngleInfoArr[self.frontMinAngleMinusIdx] or 0;
	end
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sComputeCrackShotScore(self.showData.actVo.actIdx,
		self.showData.levelInfo.diffType, angle, targetAngle, isFirst);
	-- print(angle, targetAngle, isFirst);
end

function Lua_CrackShotChallengeWindow:showShotEff(isShoting)
	if self.xiongEff == nil then
		self.xiongEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/baifabaizhogn", "baifabaizhogn", 0, -360);
		self.xiongEff.siblingIndex = 3;
	end
	self.xiongEff:setEnable(false);
	self.xiongEff:setEnable(true);

	if isShoting then
		if self.shotEff == nil then
			self.shotEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_sheji", "ui_sheji", 15, 280);
		end
		self.shotEff:setEnable(false);
		self.shotEff:setEnable(true);
	end
end

-- 获取前进方向上最近的气球
function Lua_CrackShotChallengeWindow:getFrontMinAngleMinusIdx()
	local compareAngle = self.angle;
	local len = self.balloonAngleInfoArr:getSize();
	local idx, minAngle, balloonAngle, angleMinus, minDistanceMinus;
	for i = 1, len do
		if self.balloonArr[i].isActive then
			balloonAngle = self.balloonAngleInfoArr[i];
			if self.direction == -1 then -- 顺时针/减小
				if compareAngle >= balloonAngle then
					if minDistanceMinus == nil or minDistanceMinus > compareAngle - balloonAngle then
						idx = i;
						minDistanceMinus = compareAngle - balloonAngle;
					end
				else
					if minDistanceMinus == nil or minDistanceMinus > compareAngle + 360 - balloonAngle then
						idx = i;
						minDistanceMinus = compareAngle + 360 - balloonAngle;
					end
				end
			else -- 逆时针/增大
				if compareAngle <= balloonAngle then
					if minDistanceMinus == nil or minDistanceMinus > balloonAngle - compareAngle then
						idx = i;
						minDistanceMinus = balloonAngle - compareAngle;
					end
				else
					if minDistanceMinus == nil or minDistanceMinus > balloonAngle + 360 - compareAngle then
						idx = i;
						minDistanceMinus = balloonAngle + 360 - compareAngle;
					end
				end
			end
		end
	end
	if idx then
		local maxCheckAngleRange = self.showData.levelInfo.maxCheckAngleRange;
		self.distanceMin = minDistanceMinus - maxCheckAngleRange;
		self.distanceMax = minDistanceMinus + maxCheckAngleRange;
	end
	return idx;
end

function Lua_CrackShotChallengeWindow:onBackBtnClick(go)
	if not self.isOpen then
		local tipsData = {
			owner = self,
			des = LanUtil.getValue(768019),
			btnType = 1,
			cancelLabel = LanUtil.getValue(768020),
			sureLabel = LanUtil.getValue(768021),
			cancelFun = self.hide,
		};
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	end
end

function Lua_CrackShotChallengeWindow:dispose()
	if self.balloonArr ~= nil then
		self.balloonArr:dispose();
		self.balloonArr:clear();
		self.balloonArr = nil;
	end
	if self.balloonAngleInfoArr ~= nil then
		self.balloonAngleInfoArr:dispose();
		self.balloonAngleInfoArr:clear();
		self.balloonAngleInfoArr = nil;
	end
	if self.uiEffect ~= nil then
		self.uiEffect:dispose();
		self.uiEffect = nil;
	end
	if self.xiongEff ~= nil then
		self.xiongEff:dispose();
		self.xiongEff = nil;
	end
	if self.shotEff ~= nil then
		self.shotEff:dispose();
		self.shotEff = nil;
	end

	DataCenter.connectionManager:setCollectInfo(100);
	DataCenter.crackShotData.isCrackShotTween = false;
	self.bigRoundDic = nil;
	self:endPlayTimer();
	self:superCall("dispose");
end